-module(icparse).
%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%


-export([parse/1, parse_and_scan/1, format_error/1]).

-import(lists, [reverse/1]).

-ifdef(JAM).
-compile([{parse_transform,jam_yecc_pj},pj]).
-endif.


-include("icforms.hrl").



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The parser generator will insert appropriate declarations before this line.%

parse(Tokens) ->
    case catch yeccpars1(Tokens, false, 0, [], []) of
	error ->
	    Errorline =
		if Tokens == [] -> 0; true -> element(2, hd(Tokens)) end,
	    {error,
	     {Errorline, ?MODULE, "syntax error at or after this line."}};
	Other ->
	    Other
    end.

parse_and_scan({Mod, Fun, Args}) ->
    case apply(Mod, Fun, Args) of
	{eof, _} ->
	    {ok, eof};
	{error, Descriptor, _} ->
	    {error, Descriptor};
	{ok, Tokens, _} ->
	    yeccpars1(Tokens, {Mod, Fun, Args}, 0, [], [])
    end.

format_error(Message) ->
    case io_lib:deep_char_list(Message) of
	true ->
	    Message;
	_ ->
	    io_lib:write(Message)
    end.

% To be used in grammar files to throw an error message to the parser toplevel.
% Doesn't have to be exported!
return_error(Line, Message) ->
    throw({error, {Line, ?MODULE, Message}}).


% Don't change yeccpars1/6 too much, it is called recursively by yeccpars2/8!
yeccpars1([Token | Tokens], Tokenizer, State, States, Vstack) ->
    yeccpars2(State, element(1, Token), States, Vstack, Token, Tokens,
	      Tokenizer);
yeccpars1([], {M, F, A}, State, States, Vstack) ->
    case catch apply(M, F, A) of
        {eof, Endline} ->
            {error, {Endline, ?MODULE, "end_of_file"}};
        {error, Descriptor, Endline} ->
            {error, Descriptor};
        {'EXIT', Reason} ->
            {error, {0, ?MODULE, Reason}};
        {ok, Tokens, Endline} ->
	    case catch yeccpars1(Tokens, {M, F, A}, State, States, Vstack) of
		error ->
		    Errorline = element(2, hd(Tokens)),
		    {error, {Errorline, ?MODULE,
			     "syntax error at or after this line."}};
		Other ->
		    Other
	    end
    end;
yeccpars1([], false, State, States, Vstack) ->
    yeccpars2(State, '$end', States, Vstack, {'$end', 999999}, [], false).

% For internal use only.
yeccerror(Token) ->
    {error,
     {element(2, Token), ?MODULE,
      ["syntax error before: ", yecctoken2string(Token)]}}.

yecctoken2string({atom, _, A}) -> io_lib:write(A);
yecctoken2string({integer,_,N}) -> io_lib:write(N);
yecctoken2string({float,_,F}) -> io_lib:write(F);
yecctoken2string({char,_,C}) -> io_lib:write_char(C);
yecctoken2string({var,_,V}) -> io_lib:format('~s', [V]);
yecctoken2string({string,_,S}) -> io_lib:write_string(S);
yecctoken2string({reserved_symbol, _, A}) -> io_lib:format('~w', [A]);
yecctoken2string({'dot', _}) -> io_lib:format('~w', ['.']);
yecctoken2string({'$end', _}) ->
    [];
yecctoken2string({Other, _}) when atom(Other) ->
    io_lib:format('~w', [Other]);
yecctoken2string({_, _, Other}) when list(Other), number(hd(Other)) ->
    Other;
yecctoken2string({_, _, Other}) ->
    io_lib:format('~p', [Other]);
yecctoken2string(Other) ->
    io_lib:write(Other).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%-----------------------------------------------------------




yeccpars2(0, 'exception', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'typedef', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'const', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'interface', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, 'module', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(1, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 337, [1 | __Ss], [__T | __Stack]);
yeccpars2(1, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 336, [1 | __Ss], [__T | __Stack]);
yeccpars2(1, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(2, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 335, [2 | __Ss], [__T | __Stack]);
yeccpars2(2, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(3, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1],
 yeccpars2(yeccgoto('OorM_<definition>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(4, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<type_dcl>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(5, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 334, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(6, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<interface>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(7, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 333, [7 | __Ss], [__T | __Stack]);
yeccpars2(7, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(8, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<interface>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(9, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 262, [9 | __Ss], [__T | __Stack]);
yeccpars2(9, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(10, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 261, [10 | __Ss], [__T | __Stack]);
yeccpars2(10, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(11, '$end', _, __Stack, _, _, _) ->
 {ok, hd(__Stack)};
yeccpars2(11, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(12, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<type_dcl>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(13, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 260, [13 | __Ss], [__T | __Stack]);
yeccpars2(13, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(14, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<type_dcl>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(15, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<definition>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(16, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<definition>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(17, 'exception', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'typedef', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'const', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'interface', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, 'module', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [17 | __Ss], [__T | __Stack]);
yeccpars2(17, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  reverse(__1),
 yeccpars2(yeccgoto('<specification>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(18, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'fixed', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 256, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [18 | __Ss], [__T | __Stack]);
yeccpars2(18, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(19, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 235, [19 | __Ss], [__T | __Stack]);
yeccpars2(19, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(20, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 229, [20 | __Ss], [__T | __Stack]);
yeccpars2(20, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(21, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 221, [21 | __Ss], [__T | __Stack]);
yeccpars2(21, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(22, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 216, [22 | __Ss], [__T | __Stack]);
yeccpars2(22, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(23, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 203, [23 | __Ss], [__T | __Stack]);
yeccpars2(23, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(24, 'fixed', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 144, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'sequence', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 147, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [24 | __Ss], [__T | __Stack]);
yeccpars2(24, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(25, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [25 | __Ss], [__T | __Stack]);
yeccpars2(25, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(26, 'switch', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [26 | __Ss], [__T | __Stack]);
yeccpars2(26, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(27, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [27 | __Ss], [__T | __Stack]);
yeccpars2(27, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(28, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [28 | __Ss], [__T | __Stack]);
yeccpars2(28, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(29, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 195, [29 | __Ss], [__T | __Stack]);
yeccpars2(29, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(30, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<switch_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(31, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<switch_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(32, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<switch_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(33, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ic_symtab:scoped_id_new(__1),
 yeccpars2(yeccgoto('<scoped_name>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(34, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<switch_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(35, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [35 | __Ss], [__T | __Stack]);
yeccpars2(35, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<switch_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(36, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<integer_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(37, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<signed_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(38, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<signed_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(39, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [39 | __Ss], [__T | __Stack]);
yeccpars2(39, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(40, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {unsigned,__1},
 yeccpars2(yeccgoto('<integer_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(41, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unsigned_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(42, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unsigned_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(43, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<boolean_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(44, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<char_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(45, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [45 | __Ss], [__T | __Stack]);
yeccpars2(45, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<signed_long_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(46, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<signed_short_int>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(47, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [47 | __Ss], [__T | __Stack]);
yeccpars2(47, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [47 | __Ss], [__T | __Stack]);
yeccpars2(47, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(48, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<char_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(49, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [49 | __Ss], [__T | __Stack]);
yeccpars2(49, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<unsigned_long_int>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(50, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<unsigned_short_int>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(51, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'long long',element(2,__2)},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<unsigned_long_int>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(52, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'long long',element(2,__2)},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<signed_long_int>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(53, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [53 | __Ss], [__T | __Stack]);
yeccpars2(53, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(54, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(58, __Cat, [54 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(55, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1],
 yeccpars2(yeccgoto('OorM_<case>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(56, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 194, [56 | __Ss], [__T | __Stack]);
yeccpars2(56, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(57, '}', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  reverse(lists:flatten(__1)),
 yeccpars2(yeccgoto('<switch_body>', hd(__Ss)), '}', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(57, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(58, __Cat, [57 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(58, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [58 | __Ss], [__T | __Stack]);
yeccpars2(58, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(62, __Cat, [58 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(59, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 183, [59 | __Ss], [__T | __Stack]);
yeccpars2(59, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(60, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__1],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('Ugly_pragmas', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(61, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(120, __Cat, [61 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(62, 'default', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [62 | __Ss], [__T | __Stack]);
yeccpars2(62, 'case', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [62 | __Ss], [__T | __Stack]);
yeccpars2(62, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [62 | __Ss], [__T | __Stack]);
yeccpars2(62, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(63, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(119, __Cat, [63 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(64, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [64 | __Ss], [__T | __Stack]);
yeccpars2(64, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(65, ':', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [65 | __Ss], [__T | __Stack]);
yeccpars2(65, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(66, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<case_label>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(67, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [67 | __Ss], [__T | __Stack]);
yeccpars2(67, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(68, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unary_operator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(69, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unary_operator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(70, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [70 | __Ss], [__T | __Stack]);
yeccpars2(70, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 100, [70 | __Ss], [__T | __Stack]);
yeccpars2(70, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<shift_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(71, '&', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 95, [71 | __Ss], [__T | __Stack]);
yeccpars2(71, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<xor_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(72, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(73, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(74, ':', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 116, [74 | __Ss], [__T | __Stack]);
yeccpars2(74, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(75, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(76, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(77, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(78, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<primary_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(79, '%', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 103, [79 | __Ss], [__T | __Stack]);
yeccpars2(79, '/', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 105, [79 | __Ss], [__T | __Stack]);
yeccpars2(79, '*', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 104, [79 | __Ss], [__T | __Stack]);
yeccpars2(79, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<add_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(80, '|', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 114, [80 | __Ss], [__T | __Stack]);
yeccpars2(80, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_exp>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(81, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unary_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(82, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [82 | __Ss], [__T | __Stack]);
yeccpars2(82, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<primary_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(83, '<<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 97, [83 | __Ss], [__T | __Stack]);
yeccpars2(83, '>>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 98, [83 | __Ss], [__T | __Stack]);
yeccpars2(83, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<and_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(84, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(85, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<mult_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(86, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(87, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(88, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(89, '^', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 93, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<or_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(90, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<boolean_literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(91, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<boolean_literal>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(92, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<unary_operator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(93, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(94, '&', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 95, [94 | __Ss], [__T | __Stack]);
yeccpars2(94, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'xor',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<xor_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(95, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(96, '<<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 97, [96 | __Ss], [__T | __Stack]);
yeccpars2(96, '>>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 98, [96 | __Ss], [__T | __Stack]);
yeccpars2(96, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'and',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<and_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(97, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [97 | __Ss], [__T | __Stack]);
yeccpars2(97, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(98, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [98 | __Ss], [__T | __Stack]);
yeccpars2(98, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(99, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [99 | __Ss], [__T | __Stack]);
yeccpars2(99, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 100, [99 | __Ss], [__T | __Stack]);
yeccpars2(99, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {rshift,__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<shift_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(100, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [100 | __Ss], [__T | __Stack]);
yeccpars2(100, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(101, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(102, '%', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 103, [102 | __Ss], [__T | __Stack]);
yeccpars2(102, '/', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 105, [102 | __Ss], [__T | __Stack]);
yeccpars2(102, '*', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 104, [102 | __Ss], [__T | __Stack]);
yeccpars2(102, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'-',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<add_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(103, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(104, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(105, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(106, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'/',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<mult_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(107, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'*',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<mult_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(108, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'%',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<mult_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(109, '%', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 103, [109 | __Ss], [__T | __Stack]);
yeccpars2(109, '/', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 105, [109 | __Ss], [__T | __Stack]);
yeccpars2(109, '*', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 104, [109 | __Ss], [__T | __Stack]);
yeccpars2(109, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'+',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<add_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(110, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [110 | __Ss], [__T | __Stack]);
yeccpars2(110, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 100, [110 | __Ss], [__T | __Stack]);
yeccpars2(110, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {lshift,__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<shift_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(111, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {__1,__2},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<unary_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(112, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 113, [112 | __Ss], [__T | __Stack]);
yeccpars2(112, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(113, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ic_symtab:scoped_id_add(__1,__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<scoped_name>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(114, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [114 | __Ss], [__T | __Stack]);
yeccpars2(114, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(115, '^', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 93, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {'or',__1,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<or_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(116, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<case_label>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(117, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 118, [117 | __Ss], [__T | __Stack]);
yeccpars2(117, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(118, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<primary_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(119, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [119 | __Ss], [__T | __Stack]);
yeccpars2(119, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1 ++ ([__2] ++ __3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('OorM_<case_label>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(120, 'fixed', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 144, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'sequence', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 147, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'default', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'case', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(121, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(122, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<simple_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(123, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(124, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(182, __Cat, [124 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(125, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(126, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(127, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(179, __Cat, [127 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(128, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<constr_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(129, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<template_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(130, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(131, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(132, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(133, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [133 | __Ss], [__T | __Stack]);
yeccpars2(133, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<simple_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(134, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<template_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(135, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(136, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<template_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(137, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<constr_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(138, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<simple_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(139, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 171, [139 | __Ss], [__T | __Stack]);
yeccpars2(139, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(140, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<constr_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(141, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<base_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(142, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<any_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(143, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<floating_pt_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(144, '<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [144 | __Ss], [__T | __Stack]);
yeccpars2(144, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(145, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<floating_pt_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(146, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<octet_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(147, '<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [147 | __Ss], [__T | __Stack]);
yeccpars2(147, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(148, '<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 154, [148 | __Ss], [__T | __Stack]);
yeccpars2(148, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #string{},
 yeccpars2(yeccgoto('<string_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(149, '<', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 150, [149 | __Ss], [__T | __Stack]);
yeccpars2(149, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #wstring{},
 yeccpars2(yeccgoto('<string_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(150, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(151, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<positive_int_const>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(152, '>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 153, [152 | __Ss], [__T | __Stack]);
yeccpars2(152, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(153, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #wstring{length = __3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto('<string_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(154, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [154 | __Ss], [__T | __Stack]);
yeccpars2(154, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(155, '>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [155 | __Ss], [__T | __Stack]);
yeccpars2(155, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(156, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #string{length = __3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto('<string_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(157, 'fixed', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 144, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'sequence', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 147, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(158, '>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 160, [158 | __Ss], [__T | __Stack]);
yeccpars2(158, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 159, [158 | __Ss], [__T | __Stack]);
yeccpars2(158, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(159, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(160, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #sequence{type = __3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto('<sequence_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(161, '>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [161 | __Ss], [__T | __Stack]);
yeccpars2(161, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(162, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #sequence{type = __3, length = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('<sequence_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(163, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(164, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 165, [164 | __Ss], [__T | __Stack]);
yeccpars2(164, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(165, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [165 | __Ss], [__T | __Stack]);
yeccpars2(165, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(166, '>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 167, [166 | __Ss], [__T | __Stack]);
yeccpars2(166, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(167, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #fixed{digits = __3, scale = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('<fixed_pt_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(168, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<complex_declarator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(169, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<declarator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(170, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #case_dcl{type = __1, id = __2},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<element_spec>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(171, '[', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 175, [171 | __Ss], [__T | __Stack]);
yeccpars2(171, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<simple_declarator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(172, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<declarator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(173, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1],
 yeccpars2(yeccgoto('OorM_<fixed_array_size>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(174, '[', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 175, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #array{id = __1, size = reverse(__2)},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<array_declarator>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(175, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(176, ']', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 177, [176 | __Ss], [__T | __Stack]);
yeccpars2(176, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(177, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<fixed_array_size>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(178, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__1],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('OorM_<fixed_array_size>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(179, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 180, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(180, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(181, __Cat, [180 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(181, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [181 | __Ss], [__T | __Stack]);
yeccpars2(181, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1 ++ (__3 ++ (__5 ++ (__7 ++ [__4#case_dcl{label = reverse(__2)}]))),
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto('<case>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(182, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [182 | __Ss], [__T | __Stack]);
yeccpars2(182, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ ([__3|__1] ++ __4),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto('OorM_<case_label>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(183, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 184, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(184, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 185, [184 | __Ss], [__T | __Stack]);
yeccpars2(184, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(185, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 186, [185 | __Ss], [__T | __Stack]);
yeccpars2(185, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 187, [185 | __Ss], [__T | __Stack]);
yeccpars2(185, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(186, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [186 | __Ss], [__T | __Stack]);
yeccpars2(186, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 190, [186 | __Ss], [__T | __Stack]);
yeccpars2(186, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(187, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 188, [187 | __Ss], [__T | __Stack]);
yeccpars2(187, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(188, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #pragma{type = __4, to = followed, apply = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('OE_pragma', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(189, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 192, [189 | __Ss], [__T | __Stack]);
yeccpars2(189, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(190, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 191, [190 | __Ss], [__T | __Stack]);
yeccpars2(190, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(191, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #pragma{type = __4, to = __5, apply = __6},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto('OE_pragma', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(192, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #pragma{type = __4, to = __5, apply = ic_options:float_to_version(__6)},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto('OE_pragma', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(193, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__1],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('OorM_<case>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(194, __Cat, __Ss,  [__9,__8,__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #union{id = __2, type = __5, body = __8},
 __Nss = lists:nthtail(8, __Ss),
 yeccpars2(yeccgoto('<union_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(195, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ic_symtab:scoped_id_new_global(__2),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<scoped_name>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(196, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<type_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(197, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 171, [197 | __Ss], [__T | __Stack]);
yeccpars2(197, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(198, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(200, __Cat, [198 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(199, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #typedef{type = __1, id = __2},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<type_declarator>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(200, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 201, [200 | __Ss], [__T | __Stack]);
yeccpars2(200, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|reverse(__2)],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<declarators>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(201, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 171, [201 | __Ss], [__T | __Stack]);
yeccpars2(201, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(202, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__1],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('ZorM_<declarator>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(203, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 204, [203 | __Ss], [__T | __Stack]);
yeccpars2(203, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(204, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(208, __Cat, [204 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(205, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('OorM_<member>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(206, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 215, [206 | __Ss], [__T | __Stack]);
yeccpars2(206, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(207, '}', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  reverse(__1),
 yeccpars2(yeccgoto('<member_list>', hd(__Ss)), '}', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(207, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(208, __Cat, [207 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(208, 'fixed', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 144, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'sequence', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 147, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(209, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 171, [209 | __Ss], [__T | __Stack]);
yeccpars2(209, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(210, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(211, __Cat, [210 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(211, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 212, [211 | __Ss], [__T | __Stack]);
yeccpars2(211, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [211 | __Ss], [__T | __Stack]);
yeccpars2(211, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(212, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(213, __Cat, [212 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(213, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [213 | __Ss], [__T | __Stack]);
yeccpars2(213, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1 ++ (__4 ++ (__6 ++ [#member{type = __2, id = __3}])),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('<member>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(214, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('OorM_<member>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(215, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #struct{id = __2, body = __4},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<struct_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(216, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 217, [216 | __Ss], [__T | __Stack]);
yeccpars2(216, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(217, 'exception', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'typedef', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'const', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'interface', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, 'module', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(218, 'exception', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'typedef', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'const', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'interface', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 220, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, 'module', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [218 | __Ss], [__T | __Stack]);
yeccpars2(218, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(219, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__1],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('OorM_<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(220, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #module{id = __2, body = reverse(__4)},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<module>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(221, ':', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 222, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, ';', __Ss, [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #forward{id = __2},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<forward_dcl>', hd(__Nss)), ';', __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(221, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(224, __Cat, [221 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(222, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(223, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('Opt_<inheritance_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(224, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {__2,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<interface_header>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(225, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [225 | __Ss], [__T | __Stack]);
yeccpars2(225, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(226, __Cat, [225 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(226, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 227, [226 | __Ss], [__T | __Stack]);
yeccpars2(226, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|reverse(__3)],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<inheritance_spec>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(227, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(228, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__1],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('ZorM_<scoped_name>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(229, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 230, [229 | __Ss], [__T | __Stack]);
yeccpars2(229, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(230, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(231, __Cat, [230 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(231, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [231 | __Ss], [__T | __Stack]);
yeccpars2(231, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('ZorM_<member>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(232, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 234, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(208, __Cat, [232 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(233, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('ZorM_<member>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(234, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #except{id = __2, body = reverse(__4)},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<except_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(235, '{', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 236, [235 | __Ss], [__T | __Stack]);
yeccpars2(235, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(236, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(237, __Cat, [236 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(237, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 239, [237 | __Ss], [__T | __Stack]);
yeccpars2(237, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [237 | __Ss], [__T | __Stack]);
yeccpars2(237, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(238, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(240, __Cat, [238 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(239, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #enumerator{id = __1},
 yeccpars2(yeccgoto('<enumerator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(240, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [240 | __Ss], [__T | __Stack]);
yeccpars2(240, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(241, __Cat, [240 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(241, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(242, __Cat, [241 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(242, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 243, [242 | __Ss], [__T | __Stack]);
yeccpars2(242, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 244, [242 | __Ss], [__T | __Stack]);
yeccpars2(242, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [242 | __Ss], [__T | __Stack]);
yeccpars2(242, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(243, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(245, __Cat, [243 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(244, __Cat, __Ss,  [__9,__8,__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #enum{id = __2, body = __4 ++ (__6 ++ (__8 ++ [__5|reverse(__7)]))},
 __Nss = lists:nthtail(8, __Ss),
 yeccpars2(yeccgoto('<enum_type>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(245, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 239, [245 | __Ss], [__T | __Stack]);
yeccpars2(245, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [245 | __Ss], [__T | __Stack]);
yeccpars2(245, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(246, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ (__4 ++ [__5|__1]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('ZorM_<enumerator>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(247, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(248, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(249, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 257, [249 | __Ss], [__T | __Stack]);
yeccpars2(249, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(250, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(251, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(252, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(253, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(254, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [254 | __Ss], [__T | __Stack]);
yeccpars2(254, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(255, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(256, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<fixed_pt_const_type>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(257, '=', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 258, [257 | __Ss], [__T | __Stack]);
yeccpars2(257, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(258, 'FALSE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 90, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, 'TRUE', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 91, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<floating_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<fixed_pt_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<wcharacter_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 87, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<character_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<wstring_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '~', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 92, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '+', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '-', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [258 | __Ss], [__T | __Stack]);
yeccpars2(258, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(259, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #const{type = __2, id = __3, val = __5},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<const_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(260, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(261, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(262, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(264, __Cat, [262 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(263, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 332, [263 | __Ss], [__T | __Stack]);
yeccpars2(263, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(264, 'readonly', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 277, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'oneway', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 276, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, '}', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars2(yeccgoto('<interface_body>', hd(__Ss)), '}', __Ss, __Stack, __T, __Ts, __Tzr);
yeccpars2(264, 'attribute', __Ss, __Stack, __T, __Ts, __Tzr) ->
 __Val =  nil,
 yeccpars2(275, 'attribute', [264 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(264, 'exception', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'enum', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'union', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'struct', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'typedef', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, 'const', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  nil,
 yeccpars2(274, __Cat, [264 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(265, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 331, [265 | __Ss], [__T | __Stack]);
yeccpars2(265, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(266, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 330, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(267, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 329, [267 | __Ss], [__T | __Stack]);
yeccpars2(267, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(268, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  if list(__2) -> __2 ++ __1; true -> [__2|__1] end,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('ZorM_<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(269, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('Opt_<op_attribute>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(270, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 328, [270 | __Ss], [__T | __Stack]);
yeccpars2(270, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(271, ';', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 327, [271 | __Ss], [__T | __Stack]);
yeccpars2(271, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(272, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<export>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(273, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<export>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(274, 'void', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 290, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [274 | __Ss], [__T | __Stack]);
yeccpars2(274, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(275, 'attribute', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 278, [275 | __Ss], [__T | __Stack]);
yeccpars2(275, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(276, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<op_attribute>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(277, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('Opt_readonly', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(278, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [278 | __Ss], [__T | __Stack]);
yeccpars2(278, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(279, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(280, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 283, [280 | __Ss], [__T | __Stack]);
yeccpars2(280, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(281, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [281 | __Ss], [__T | __Stack]);
yeccpars2(281, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(282, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(283, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<simple_declarator>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(284, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(285, __Cat, [284 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(285, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 286, [285 | __Ss], [__T | __Stack]);
yeccpars2(285, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #attr{readonly = __1, type = __3, id = [__4|reverse(__5)]},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<attr_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(286, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 283, [286 | __Ss], [__T | __Stack]);
yeccpars2(286, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(287, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__1],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('ZorM_<simple_declarator>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(288, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 291, [288 | __Ss], [__T | __Stack]);
yeccpars2(288, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(289, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<op_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(290, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<op_type_spec>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(291, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 292, [291 | __Ss], [__T | __Stack]);
yeccpars2(291, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(292, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(310, __Cat, [292 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(293, 'raises', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 296, [293 | __Ss], [__T | __Stack]);
yeccpars2(293, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(295, __Cat, [293 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(294, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('Opt_<raises_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(295, 'context', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 303, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(302, __Cat, [295 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(296, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 297, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(297, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [297 | __Ss], [__T | __Stack]);
yeccpars2(297, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [297 | __Ss], [__T | __Stack]);
yeccpars2(297, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(298, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 112, [298 | __Ss], [__T | __Stack]);
yeccpars2(298, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(299, __Cat, [298 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(299, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 300, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 227, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(300, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|reverse(__4)],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<raises_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(301, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('Opt_<context_expr>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(302, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #op{oneway = __1, type = __2, id = __3, params = __4, raises = __5, ctx = __6},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('<op_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(303, '(', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 304, [303 | __Ss], [__T | __Stack]);
yeccpars2(303, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(304, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 305, [304 | __Ss], [__T | __Stack]);
yeccpars2(304, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(305, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(306, __Cat, [305 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(306, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 308, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 307, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(307, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|reverse(__4)],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<context_expr>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(308, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 309, [308 | __Ss], [__T | __Stack]);
yeccpars2(308, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(309, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__1],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('ZorM_<string_literal>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(310, 'inout', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 315, [310 | __Ss], [__T | __Stack]);
yeccpars2(310, 'out', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 316, [310 | __Ss], [__T | __Stack]);
yeccpars2(310, 'in', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 314, [310 | __Ss], [__T | __Stack]);
yeccpars2(310, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 311, [310 | __Ss], [__T | __Stack]);
yeccpars2(310, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [310 | __Ss], [__T | __Stack]);
yeccpars2(310, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(311, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<parameter_dcls>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(312, 'wstring', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 149, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'string', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 148, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'any', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 142, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'octet', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 146, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'boolean', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'wchar', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'char', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'unsigned', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'short', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'long', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'double', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 143, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'float', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 145, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, 'Object', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 141, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, '::', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(313, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(317, __Cat, [313 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(314, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_attribute>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(315, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_attribute>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(316, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('<param_attribute>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(317, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [317 | __Ss], [__T | __Stack]);
yeccpars2(317, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto('ZorM_<param_dcl>', hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(318, ')', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 319, [318 | __Ss], [__T | __Stack]);
yeccpars2(318, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(320, __Cat, [318 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(319, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ [__3|reverse(__4)],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('<parameter_dcls>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(320, ',', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 321, [320 | __Ss], [__T | __Stack]);
yeccpars2(320, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [320 | __Ss], [__T | __Stack]);
yeccpars2(320, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(321, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(322, __Cat, [321 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(322, 'inout', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 315, [322 | __Ss], [__T | __Stack]);
yeccpars2(322, 'out', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 316, [322 | __Ss], [__T | __Stack]);
yeccpars2(322, 'in', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 314, [322 | __Ss], [__T | __Stack]);
yeccpars2(322, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [322 | __Ss], [__T | __Stack]);
yeccpars2(322, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(323, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(324, __Cat, [323 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(324, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [324 | __Ss], [__T | __Stack]);
yeccpars2(324, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2 ++ (__4 ++ (__6 ++ [__5|__1])),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto('ZorM_<param_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(325, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 283, [325 | __Ss], [__T | __Stack]);
yeccpars2(325, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(326, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #param{inout = __1, type = __2, id = __3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto('<param_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(327, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(328, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(329, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(330, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(331, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<export>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(332, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #interface{id = element(1,__1), inherit = element(2,__1), body = lists:reverse(__3)},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto('<interface_dcl>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(333, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(334, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(335, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('<definition>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(336, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('OE_preproc', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(337, '<string_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 338, [337 | __Ss], [__T | __Stack]);
yeccpars2(337, '<identifier>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 184, [337 | __Ss], [__T | __Stack]);
yeccpars2(337, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(338, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 339, [338 | __Ss], [__T | __Stack]);
yeccpars2(338, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(340, __Cat, [338 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(339, '<integer_literal>', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 339, [339 | __Ss], [__T | __Stack]);
yeccpars2(339, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(342, __Cat, [339 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(340, '#', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 341, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(341, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  case __4 of [] -> case __2 of {_,_,"1"} -> #preproc{cat = line_nr, id = __3, aux = __4}; _ -> [] end; _ -> #preproc{cat = line_nr, id = __3, aux = __4} end,
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto('OE_preproc', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(342, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto('ZorM_<integer_literal>', hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(__Other, _, _, _, _, _, _) ->
 exit({parser, __Other, missing_state_in_action_table}).

yeccgoto('<add_expr>', 64) ->
 70;
yeccgoto('<add_expr>', 67) ->
 70;
yeccgoto('<add_expr>', 93) ->
 70;
yeccgoto('<add_expr>', 95) ->
 70;
yeccgoto('<add_expr>', 97) ->
 110;
yeccgoto('<add_expr>', 98) ->
 99;
yeccgoto('<add_expr>', 114) ->
 70;
yeccgoto('<add_expr>', 150) ->
 70;
yeccgoto('<add_expr>', 154) ->
 70;
yeccgoto('<add_expr>', 159) ->
 70;
yeccgoto('<add_expr>', 163) ->
 70;
yeccgoto('<add_expr>', 165) ->
 70;
yeccgoto('<add_expr>', 175) ->
 70;
yeccgoto('<add_expr>', 258) ->
 70;
yeccgoto('<and_expr>', 64) ->
 71;
yeccgoto('<and_expr>', 67) ->
 71;
yeccgoto('<and_expr>', 93) ->
 94;
yeccgoto('<and_expr>', 114) ->
 71;
yeccgoto('<and_expr>', 150) ->
 71;
yeccgoto('<and_expr>', 154) ->
 71;
yeccgoto('<and_expr>', 159) ->
 71;
yeccgoto('<and_expr>', 163) ->
 71;
yeccgoto('<and_expr>', 165) ->
 71;
yeccgoto('<and_expr>', 175) ->
 71;
yeccgoto('<and_expr>', 258) ->
 71;
yeccgoto('<any_type>', 24) ->
 121;
yeccgoto('<any_type>', 120) ->
 121;
yeccgoto('<any_type>', 157) ->
 121;
yeccgoto('<any_type>', 208) ->
 121;
yeccgoto('<any_type>', 274) ->
 121;
yeccgoto('<any_type>', 278) ->
 121;
yeccgoto('<any_type>', 312) ->
 121;
yeccgoto('<array_declarator>', 139) ->
 168;
yeccgoto('<array_declarator>', 197) ->
 168;
yeccgoto('<array_declarator>', 201) ->
 168;
yeccgoto('<array_declarator>', 209) ->
 168;
yeccgoto('<attr_dcl>', 264) ->
 265;
yeccgoto('<base_type_spec>', 24) ->
 122;
yeccgoto('<base_type_spec>', 120) ->
 122;
yeccgoto('<base_type_spec>', 157) ->
 122;
yeccgoto('<base_type_spec>', 208) ->
 122;
yeccgoto('<base_type_spec>', 274) ->
 279;
yeccgoto('<base_type_spec>', 278) ->
 279;
yeccgoto('<base_type_spec>', 312) ->
 279;
yeccgoto('<boolean_literal>', 64) ->
 72;
yeccgoto('<boolean_literal>', 67) ->
 72;
yeccgoto('<boolean_literal>', 86) ->
 72;
yeccgoto('<boolean_literal>', 93) ->
 72;
yeccgoto('<boolean_literal>', 95) ->
 72;
yeccgoto('<boolean_literal>', 97) ->
 72;
yeccgoto('<boolean_literal>', 98) ->
 72;
yeccgoto('<boolean_literal>', 100) ->
 72;
yeccgoto('<boolean_literal>', 101) ->
 72;
yeccgoto('<boolean_literal>', 103) ->
 72;
yeccgoto('<boolean_literal>', 104) ->
 72;
yeccgoto('<boolean_literal>', 105) ->
 72;
yeccgoto('<boolean_literal>', 114) ->
 72;
yeccgoto('<boolean_literal>', 150) ->
 72;
yeccgoto('<boolean_literal>', 154) ->
 72;
yeccgoto('<boolean_literal>', 159) ->
 72;
yeccgoto('<boolean_literal>', 163) ->
 72;
yeccgoto('<boolean_literal>', 165) ->
 72;
yeccgoto('<boolean_literal>', 175) ->
 72;
yeccgoto('<boolean_literal>', 258) ->
 72;
yeccgoto('<boolean_type>', 18) ->
 247;
yeccgoto('<boolean_type>', 24) ->
 123;
yeccgoto('<boolean_type>', 28) ->
 30;
yeccgoto('<boolean_type>', 120) ->
 123;
yeccgoto('<boolean_type>', 157) ->
 123;
yeccgoto('<boolean_type>', 208) ->
 123;
yeccgoto('<boolean_type>', 274) ->
 123;
yeccgoto('<boolean_type>', 278) ->
 123;
yeccgoto('<boolean_type>', 312) ->
 123;
yeccgoto('<case>', 54) ->
 55;
yeccgoto('<case>', 57) ->
 193;
yeccgoto('<case_label>', 62) ->
 63;
yeccgoto('<case_label>', 120) ->
 124;
yeccgoto('<char_type>', 18) ->
 248;
yeccgoto('<char_type>', 24) ->
 125;
yeccgoto('<char_type>', 28) ->
 31;
yeccgoto('<char_type>', 120) ->
 125;
yeccgoto('<char_type>', 157) ->
 125;
yeccgoto('<char_type>', 208) ->
 125;
yeccgoto('<char_type>', 274) ->
 125;
yeccgoto('<char_type>', 278) ->
 125;
yeccgoto('<char_type>', 312) ->
 125;
yeccgoto('<complex_declarator>', 139) ->
 169;
yeccgoto('<complex_declarator>', 197) ->
 169;
yeccgoto('<complex_declarator>', 201) ->
 169;
yeccgoto('<complex_declarator>', 209) ->
 169;
yeccgoto('<const_dcl>', 0) ->
 2;
yeccgoto('<const_dcl>', 17) ->
 2;
yeccgoto('<const_dcl>', 217) ->
 2;
yeccgoto('<const_dcl>', 218) ->
 2;
yeccgoto('<const_dcl>', 264) ->
 266;
yeccgoto('<const_exp>', 64) ->
 74;
yeccgoto('<const_exp>', 67) ->
 117;
yeccgoto('<const_exp>', 150) ->
 151;
yeccgoto('<const_exp>', 154) ->
 151;
yeccgoto('<const_exp>', 159) ->
 151;
yeccgoto('<const_exp>', 163) ->
 151;
yeccgoto('<const_exp>', 165) ->
 151;
yeccgoto('<const_exp>', 175) ->
 151;
yeccgoto('<const_exp>', 258) ->
 259;
yeccgoto('<const_type>', 18) ->
 249;
yeccgoto('<constr_type_spec>', 24) ->
 126;
yeccgoto('<constr_type_spec>', 120) ->
 126;
yeccgoto('<constr_type_spec>', 208) ->
 126;
yeccgoto('<context_expr>', 295) ->
 301;
yeccgoto('<declarator>', 139) ->
 170;
yeccgoto('<declarator>', 197) ->
 198;
yeccgoto('<declarator>', 201) ->
 202;
yeccgoto('<declarator>', 209) ->
 198;
yeccgoto('<declarators>', 197) ->
 199;
yeccgoto('<declarators>', 209) ->
 210;
yeccgoto('<definition>', 0) ->
 3;
yeccgoto('<definition>', 17) ->
 219;
yeccgoto('<definition>', 217) ->
 3;
yeccgoto('<definition>', 218) ->
 219;
yeccgoto('<element_spec>', 120) ->
 127;
yeccgoto('<enum_type>', 0) ->
 4;
yeccgoto('<enum_type>', 17) ->
 4;
yeccgoto('<enum_type>', 24) ->
 128;
yeccgoto('<enum_type>', 28) ->
 32;
yeccgoto('<enum_type>', 120) ->
 128;
yeccgoto('<enum_type>', 208) ->
 128;
yeccgoto('<enum_type>', 217) ->
 4;
yeccgoto('<enum_type>', 218) ->
 4;
yeccgoto('<enum_type>', 264) ->
 4;
yeccgoto('<enumerator>', 237) ->
 238;
yeccgoto('<enumerator>', 245) ->
 246;
yeccgoto('<except_dcl>', 0) ->
 5;
yeccgoto('<except_dcl>', 17) ->
 5;
yeccgoto('<except_dcl>', 217) ->
 5;
yeccgoto('<except_dcl>', 218) ->
 5;
yeccgoto('<except_dcl>', 264) ->
 267;
yeccgoto('<export>', 264) ->
 268;
yeccgoto('<fixed_array_size>', 171) ->
 173;
yeccgoto('<fixed_array_size>', 174) ->
 178;
yeccgoto('<fixed_pt_const_type>', 18) ->
 250;
yeccgoto('<fixed_pt_type>', 24) ->
 129;
yeccgoto('<fixed_pt_type>', 120) ->
 129;
yeccgoto('<fixed_pt_type>', 157) ->
 129;
yeccgoto('<fixed_pt_type>', 208) ->
 129;
yeccgoto('<floating_pt_type>', 18) ->
 251;
yeccgoto('<floating_pt_type>', 24) ->
 130;
yeccgoto('<floating_pt_type>', 120) ->
 130;
yeccgoto('<floating_pt_type>', 157) ->
 130;
yeccgoto('<floating_pt_type>', 208) ->
 130;
yeccgoto('<floating_pt_type>', 274) ->
 130;
yeccgoto('<floating_pt_type>', 278) ->
 130;
yeccgoto('<floating_pt_type>', 312) ->
 130;
yeccgoto('<forward_dcl>', 0) ->
 6;
yeccgoto('<forward_dcl>', 17) ->
 6;
yeccgoto('<forward_dcl>', 217) ->
 6;
yeccgoto('<forward_dcl>', 218) ->
 6;
yeccgoto('<inheritance_spec>', 221) ->
 223;
yeccgoto('<integer_type>', 18) ->
 252;
yeccgoto('<integer_type>', 24) ->
 131;
yeccgoto('<integer_type>', 28) ->
 34;
yeccgoto('<integer_type>', 120) ->
 131;
yeccgoto('<integer_type>', 157) ->
 131;
yeccgoto('<integer_type>', 208) ->
 131;
yeccgoto('<integer_type>', 274) ->
 131;
yeccgoto('<integer_type>', 278) ->
 131;
yeccgoto('<integer_type>', 312) ->
 131;
yeccgoto('<interface>', 0) ->
 7;
yeccgoto('<interface>', 17) ->
 7;
yeccgoto('<interface>', 217) ->
 7;
yeccgoto('<interface>', 218) ->
 7;
yeccgoto('<interface_body>', 262) ->
 263;
yeccgoto('<interface_dcl>', 0) ->
 8;
yeccgoto('<interface_dcl>', 17) ->
 8;
yeccgoto('<interface_dcl>', 217) ->
 8;
yeccgoto('<interface_dcl>', 218) ->
 8;
yeccgoto('<interface_header>', 0) ->
 9;
yeccgoto('<interface_header>', 17) ->
 9;
yeccgoto('<interface_header>', 217) ->
 9;
yeccgoto('<interface_header>', 218) ->
 9;
yeccgoto('<literal>', 64) ->
 78;
yeccgoto('<literal>', 67) ->
 78;
yeccgoto('<literal>', 86) ->
 78;
yeccgoto('<literal>', 93) ->
 78;
yeccgoto('<literal>', 95) ->
 78;
yeccgoto('<literal>', 97) ->
 78;
yeccgoto('<literal>', 98) ->
 78;
yeccgoto('<literal>', 100) ->
 78;
yeccgoto('<literal>', 101) ->
 78;
yeccgoto('<literal>', 103) ->
 78;
yeccgoto('<literal>', 104) ->
 78;
yeccgoto('<literal>', 105) ->
 78;
yeccgoto('<literal>', 114) ->
 78;
yeccgoto('<literal>', 150) ->
 78;
yeccgoto('<literal>', 154) ->
 78;
yeccgoto('<literal>', 159) ->
 78;
yeccgoto('<literal>', 163) ->
 78;
yeccgoto('<literal>', 165) ->
 78;
yeccgoto('<literal>', 175) ->
 78;
yeccgoto('<literal>', 258) ->
 78;
yeccgoto('<member>', 204) ->
 205;
yeccgoto('<member>', 207) ->
 214;
yeccgoto('<member>', 232) ->
 233;
yeccgoto('<member_list>', 204) ->
 206;
yeccgoto('<module>', 0) ->
 10;
yeccgoto('<module>', 17) ->
 10;
yeccgoto('<module>', 217) ->
 10;
yeccgoto('<module>', 218) ->
 10;
yeccgoto('<mult_expr>', 64) ->
 79;
yeccgoto('<mult_expr>', 67) ->
 79;
yeccgoto('<mult_expr>', 93) ->
 79;
yeccgoto('<mult_expr>', 95) ->
 79;
yeccgoto('<mult_expr>', 97) ->
 79;
yeccgoto('<mult_expr>', 98) ->
 79;
yeccgoto('<mult_expr>', 100) ->
 109;
yeccgoto('<mult_expr>', 101) ->
 102;
yeccgoto('<mult_expr>', 114) ->
 79;
yeccgoto('<mult_expr>', 150) ->
 79;
yeccgoto('<mult_expr>', 154) ->
 79;
yeccgoto('<mult_expr>', 159) ->
 79;
yeccgoto('<mult_expr>', 163) ->
 79;
yeccgoto('<mult_expr>', 165) ->
 79;
yeccgoto('<mult_expr>', 175) ->
 79;
yeccgoto('<mult_expr>', 258) ->
 79;
yeccgoto('<octet_type>', 18) ->
 253;
yeccgoto('<octet_type>', 24) ->
 132;
yeccgoto('<octet_type>', 120) ->
 132;
yeccgoto('<octet_type>', 157) ->
 132;
yeccgoto('<octet_type>', 208) ->
 132;
yeccgoto('<octet_type>', 274) ->
 132;
yeccgoto('<octet_type>', 278) ->
 132;
yeccgoto('<octet_type>', 312) ->
 132;
yeccgoto('<op_attribute>', 264) ->
 269;
yeccgoto('<op_dcl>', 264) ->
 270;
yeccgoto('<op_type_spec>', 274) ->
 288;
yeccgoto('<or_expr>', 64) ->
 80;
yeccgoto('<or_expr>', 67) ->
 80;
yeccgoto('<or_expr>', 150) ->
 80;
yeccgoto('<or_expr>', 154) ->
 80;
yeccgoto('<or_expr>', 159) ->
 80;
yeccgoto('<or_expr>', 163) ->
 80;
yeccgoto('<or_expr>', 165) ->
 80;
yeccgoto('<or_expr>', 175) ->
 80;
yeccgoto('<or_expr>', 258) ->
 80;
yeccgoto('<param_attribute>', 310) ->
 312;
yeccgoto('<param_attribute>', 322) ->
 312;
yeccgoto('<param_dcl>', 310) ->
 313;
yeccgoto('<param_dcl>', 322) ->
 323;
yeccgoto('<param_type_spec>', 274) ->
 289;
yeccgoto('<param_type_spec>', 278) ->
 280;
yeccgoto('<param_type_spec>', 312) ->
 325;
yeccgoto('<parameter_dcls>', 291) ->
 293;
yeccgoto('<positive_int_const>', 150) ->
 152;
yeccgoto('<positive_int_const>', 154) ->
 155;
yeccgoto('<positive_int_const>', 159) ->
 161;
yeccgoto('<positive_int_const>', 163) ->
 164;
yeccgoto('<positive_int_const>', 165) ->
 166;
yeccgoto('<positive_int_const>', 175) ->
 176;
yeccgoto('<primary_expr>', 64) ->
 81;
yeccgoto('<primary_expr>', 67) ->
 81;
yeccgoto('<primary_expr>', 86) ->
 111;
yeccgoto('<primary_expr>', 93) ->
 81;
yeccgoto('<primary_expr>', 95) ->
 81;
yeccgoto('<primary_expr>', 97) ->
 81;
yeccgoto('<primary_expr>', 98) ->
 81;
yeccgoto('<primary_expr>', 100) ->
 81;
yeccgoto('<primary_expr>', 101) ->
 81;
yeccgoto('<primary_expr>', 103) ->
 81;
yeccgoto('<primary_expr>', 104) ->
 81;
yeccgoto('<primary_expr>', 105) ->
 81;
yeccgoto('<primary_expr>', 114) ->
 81;
yeccgoto('<primary_expr>', 150) ->
 81;
yeccgoto('<primary_expr>', 154) ->
 81;
yeccgoto('<primary_expr>', 159) ->
 81;
yeccgoto('<primary_expr>', 163) ->
 81;
yeccgoto('<primary_expr>', 165) ->
 81;
yeccgoto('<primary_expr>', 175) ->
 81;
yeccgoto('<primary_expr>', 258) ->
 81;
yeccgoto('<raises_expr>', 293) ->
 294;
yeccgoto('<scoped_name>', 18) ->
 254;
yeccgoto('<scoped_name>', 24) ->
 133;
yeccgoto('<scoped_name>', 28) ->
 35;
yeccgoto('<scoped_name>', 64) ->
 82;
yeccgoto('<scoped_name>', 67) ->
 82;
yeccgoto('<scoped_name>', 86) ->
 82;
yeccgoto('<scoped_name>', 93) ->
 82;
yeccgoto('<scoped_name>', 95) ->
 82;
yeccgoto('<scoped_name>', 97) ->
 82;
yeccgoto('<scoped_name>', 98) ->
 82;
yeccgoto('<scoped_name>', 100) ->
 82;
yeccgoto('<scoped_name>', 101) ->
 82;
yeccgoto('<scoped_name>', 103) ->
 82;
yeccgoto('<scoped_name>', 104) ->
 82;
yeccgoto('<scoped_name>', 105) ->
 82;
yeccgoto('<scoped_name>', 114) ->
 82;
yeccgoto('<scoped_name>', 120) ->
 133;
yeccgoto('<scoped_name>', 150) ->
 82;
yeccgoto('<scoped_name>', 154) ->
 82;
yeccgoto('<scoped_name>', 157) ->
 133;
yeccgoto('<scoped_name>', 159) ->
 82;
yeccgoto('<scoped_name>', 163) ->
 82;
yeccgoto('<scoped_name>', 165) ->
 82;
yeccgoto('<scoped_name>', 175) ->
 82;
yeccgoto('<scoped_name>', 208) ->
 133;
yeccgoto('<scoped_name>', 222) ->
 225;
yeccgoto('<scoped_name>', 227) ->
 228;
yeccgoto('<scoped_name>', 258) ->
 82;
yeccgoto('<scoped_name>', 274) ->
 281;
yeccgoto('<scoped_name>', 278) ->
 281;
yeccgoto('<scoped_name>', 297) ->
 298;
yeccgoto('<scoped_name>', 312) ->
 281;
yeccgoto('<sequence_type>', 24) ->
 134;
yeccgoto('<sequence_type>', 120) ->
 134;
yeccgoto('<sequence_type>', 157) ->
 134;
yeccgoto('<sequence_type>', 208) ->
 134;
yeccgoto('<shift_expr>', 64) ->
 83;
yeccgoto('<shift_expr>', 67) ->
 83;
yeccgoto('<shift_expr>', 93) ->
 83;
yeccgoto('<shift_expr>', 95) ->
 96;
yeccgoto('<shift_expr>', 114) ->
 83;
yeccgoto('<shift_expr>', 150) ->
 83;
yeccgoto('<shift_expr>', 154) ->
 83;
yeccgoto('<shift_expr>', 159) ->
 83;
yeccgoto('<shift_expr>', 163) ->
 83;
yeccgoto('<shift_expr>', 165) ->
 83;
yeccgoto('<shift_expr>', 175) ->
 83;
yeccgoto('<shift_expr>', 258) ->
 83;
yeccgoto('<signed_int>', 18) ->
 36;
yeccgoto('<signed_int>', 24) ->
 36;
yeccgoto('<signed_int>', 28) ->
 36;
yeccgoto('<signed_int>', 120) ->
 36;
yeccgoto('<signed_int>', 157) ->
 36;
yeccgoto('<signed_int>', 208) ->
 36;
yeccgoto('<signed_int>', 274) ->
 36;
yeccgoto('<signed_int>', 278) ->
 36;
yeccgoto('<signed_int>', 312) ->
 36;
yeccgoto('<signed_long_int>', 18) ->
 37;
yeccgoto('<signed_long_int>', 24) ->
 37;
yeccgoto('<signed_long_int>', 28) ->
 37;
yeccgoto('<signed_long_int>', 120) ->
 37;
yeccgoto('<signed_long_int>', 157) ->
 37;
yeccgoto('<signed_long_int>', 208) ->
 37;
yeccgoto('<signed_long_int>', 274) ->
 37;
yeccgoto('<signed_long_int>', 278) ->
 37;
yeccgoto('<signed_long_int>', 312) ->
 37;
yeccgoto('<signed_short_int>', 18) ->
 38;
yeccgoto('<signed_short_int>', 24) ->
 38;
yeccgoto('<signed_short_int>', 28) ->
 38;
yeccgoto('<signed_short_int>', 120) ->
 38;
yeccgoto('<signed_short_int>', 157) ->
 38;
yeccgoto('<signed_short_int>', 208) ->
 38;
yeccgoto('<signed_short_int>', 274) ->
 38;
yeccgoto('<signed_short_int>', 278) ->
 38;
yeccgoto('<signed_short_int>', 312) ->
 38;
yeccgoto('<simple_declarator>', 139) ->
 172;
yeccgoto('<simple_declarator>', 197) ->
 172;
yeccgoto('<simple_declarator>', 201) ->
 172;
yeccgoto('<simple_declarator>', 209) ->
 172;
yeccgoto('<simple_declarator>', 280) ->
 284;
yeccgoto('<simple_declarator>', 286) ->
 287;
yeccgoto('<simple_declarator>', 325) ->
 326;
yeccgoto('<simple_type_spec>', 24) ->
 135;
yeccgoto('<simple_type_spec>', 120) ->
 135;
yeccgoto('<simple_type_spec>', 157) ->
 158;
yeccgoto('<simple_type_spec>', 208) ->
 135;
yeccgoto('<specification>', 0) ->
 11;
yeccgoto('<string_type>', 18) ->
 255;
yeccgoto('<string_type>', 24) ->
 136;
yeccgoto('<string_type>', 120) ->
 136;
yeccgoto('<string_type>', 157) ->
 136;
yeccgoto('<string_type>', 208) ->
 136;
yeccgoto('<string_type>', 274) ->
 282;
yeccgoto('<string_type>', 278) ->
 282;
yeccgoto('<string_type>', 312) ->
 282;
yeccgoto('<struct_type>', 0) ->
 12;
yeccgoto('<struct_type>', 17) ->
 12;
yeccgoto('<struct_type>', 24) ->
 137;
yeccgoto('<struct_type>', 120) ->
 137;
yeccgoto('<struct_type>', 208) ->
 137;
yeccgoto('<struct_type>', 217) ->
 12;
yeccgoto('<struct_type>', 218) ->
 12;
yeccgoto('<struct_type>', 264) ->
 12;
yeccgoto('<switch_body>', 54) ->
 56;
yeccgoto('<switch_type_spec>', 28) ->
 39;
yeccgoto('<template_type_spec>', 24) ->
 138;
yeccgoto('<template_type_spec>', 120) ->
 138;
yeccgoto('<template_type_spec>', 157) ->
 138;
yeccgoto('<template_type_spec>', 208) ->
 138;
yeccgoto('<type_dcl>', 0) ->
 13;
yeccgoto('<type_dcl>', 17) ->
 13;
yeccgoto('<type_dcl>', 217) ->
 13;
yeccgoto('<type_dcl>', 218) ->
 13;
yeccgoto('<type_dcl>', 264) ->
 271;
yeccgoto('<type_declarator>', 24) ->
 196;
yeccgoto('<type_spec>', 24) ->
 197;
yeccgoto('<type_spec>', 120) ->
 139;
yeccgoto('<type_spec>', 208) ->
 209;
yeccgoto('<unary_expr>', 64) ->
 85;
yeccgoto('<unary_expr>', 67) ->
 85;
yeccgoto('<unary_expr>', 93) ->
 85;
yeccgoto('<unary_expr>', 95) ->
 85;
yeccgoto('<unary_expr>', 97) ->
 85;
yeccgoto('<unary_expr>', 98) ->
 85;
yeccgoto('<unary_expr>', 100) ->
 85;
yeccgoto('<unary_expr>', 101) ->
 85;
yeccgoto('<unary_expr>', 103) ->
 108;
yeccgoto('<unary_expr>', 104) ->
 107;
yeccgoto('<unary_expr>', 105) ->
 106;
yeccgoto('<unary_expr>', 114) ->
 85;
yeccgoto('<unary_expr>', 150) ->
 85;
yeccgoto('<unary_expr>', 154) ->
 85;
yeccgoto('<unary_expr>', 159) ->
 85;
yeccgoto('<unary_expr>', 163) ->
 85;
yeccgoto('<unary_expr>', 165) ->
 85;
yeccgoto('<unary_expr>', 175) ->
 85;
yeccgoto('<unary_expr>', 258) ->
 85;
yeccgoto('<unary_operator>', 64) ->
 86;
yeccgoto('<unary_operator>', 67) ->
 86;
yeccgoto('<unary_operator>', 93) ->
 86;
yeccgoto('<unary_operator>', 95) ->
 86;
yeccgoto('<unary_operator>', 97) ->
 86;
yeccgoto('<unary_operator>', 98) ->
 86;
yeccgoto('<unary_operator>', 100) ->
 86;
yeccgoto('<unary_operator>', 101) ->
 86;
yeccgoto('<unary_operator>', 103) ->
 86;
yeccgoto('<unary_operator>', 104) ->
 86;
yeccgoto('<unary_operator>', 105) ->
 86;
yeccgoto('<unary_operator>', 114) ->
 86;
yeccgoto('<unary_operator>', 150) ->
 86;
yeccgoto('<unary_operator>', 154) ->
 86;
yeccgoto('<unary_operator>', 159) ->
 86;
yeccgoto('<unary_operator>', 163) ->
 86;
yeccgoto('<unary_operator>', 165) ->
 86;
yeccgoto('<unary_operator>', 175) ->
 86;
yeccgoto('<unary_operator>', 258) ->
 86;
yeccgoto('<union_type>', 0) ->
 14;
yeccgoto('<union_type>', 17) ->
 14;
yeccgoto('<union_type>', 24) ->
 140;
yeccgoto('<union_type>', 120) ->
 140;
yeccgoto('<union_type>', 208) ->
 140;
yeccgoto('<union_type>', 217) ->
 14;
yeccgoto('<union_type>', 218) ->
 14;
yeccgoto('<union_type>', 264) ->
 14;
yeccgoto('<unsigned_int>', 18) ->
 40;
yeccgoto('<unsigned_int>', 24) ->
 40;
yeccgoto('<unsigned_int>', 28) ->
 40;
yeccgoto('<unsigned_int>', 120) ->
 40;
yeccgoto('<unsigned_int>', 157) ->
 40;
yeccgoto('<unsigned_int>', 208) ->
 40;
yeccgoto('<unsigned_int>', 274) ->
 40;
yeccgoto('<unsigned_int>', 278) ->
 40;
yeccgoto('<unsigned_int>', 312) ->
 40;
yeccgoto('<unsigned_long_int>', 18) ->
 41;
yeccgoto('<unsigned_long_int>', 24) ->
 41;
yeccgoto('<unsigned_long_int>', 28) ->
 41;
yeccgoto('<unsigned_long_int>', 120) ->
 41;
yeccgoto('<unsigned_long_int>', 157) ->
 41;
yeccgoto('<unsigned_long_int>', 208) ->
 41;
yeccgoto('<unsigned_long_int>', 274) ->
 41;
yeccgoto('<unsigned_long_int>', 278) ->
 41;
yeccgoto('<unsigned_long_int>', 312) ->
 41;
yeccgoto('<unsigned_short_int>', 18) ->
 42;
yeccgoto('<unsigned_short_int>', 24) ->
 42;
yeccgoto('<unsigned_short_int>', 28) ->
 42;
yeccgoto('<unsigned_short_int>', 120) ->
 42;
yeccgoto('<unsigned_short_int>', 157) ->
 42;
yeccgoto('<unsigned_short_int>', 208) ->
 42;
yeccgoto('<unsigned_short_int>', 274) ->
 42;
yeccgoto('<unsigned_short_int>', 278) ->
 42;
yeccgoto('<unsigned_short_int>', 312) ->
 42;
yeccgoto('<xor_expr>', 64) ->
 89;
yeccgoto('<xor_expr>', 67) ->
 89;
yeccgoto('<xor_expr>', 114) ->
 115;
yeccgoto('<xor_expr>', 150) ->
 89;
yeccgoto('<xor_expr>', 154) ->
 89;
yeccgoto('<xor_expr>', 159) ->
 89;
yeccgoto('<xor_expr>', 163) ->
 89;
yeccgoto('<xor_expr>', 165) ->
 89;
yeccgoto('<xor_expr>', 175) ->
 89;
yeccgoto('<xor_expr>', 258) ->
 89;
yeccgoto('OE_pragma', 0) ->
 15;
yeccgoto('OE_pragma', 17) ->
 15;
yeccgoto('OE_pragma', 58) ->
 60;
yeccgoto('OE_pragma', 62) ->
 60;
yeccgoto('OE_pragma', 119) ->
 60;
yeccgoto('OE_pragma', 120) ->
 60;
yeccgoto('OE_pragma', 179) ->
 60;
yeccgoto('OE_pragma', 181) ->
 60;
yeccgoto('OE_pragma', 182) ->
 60;
yeccgoto('OE_pragma', 208) ->
 60;
yeccgoto('OE_pragma', 211) ->
 60;
yeccgoto('OE_pragma', 213) ->
 60;
yeccgoto('OE_pragma', 217) ->
 15;
yeccgoto('OE_pragma', 218) ->
 15;
yeccgoto('OE_pragma', 231) ->
 60;
yeccgoto('OE_pragma', 237) ->
 60;
yeccgoto('OE_pragma', 240) ->
 60;
yeccgoto('OE_pragma', 242) ->
 60;
yeccgoto('OE_pragma', 245) ->
 60;
yeccgoto('OE_pragma', 264) ->
 272;
yeccgoto('OE_pragma', 310) ->
 60;
yeccgoto('OE_pragma', 317) ->
 60;
yeccgoto('OE_pragma', 320) ->
 60;
yeccgoto('OE_pragma', 322) ->
 60;
yeccgoto('OE_pragma', 324) ->
 60;
yeccgoto('OE_preproc', 0) ->
 16;
yeccgoto('OE_preproc', 17) ->
 16;
yeccgoto('OE_preproc', 217) ->
 16;
yeccgoto('OE_preproc', 218) ->
 16;
yeccgoto('OE_preproc', 264) ->
 273;
yeccgoto('OorM_<case>', 54) ->
 57;
yeccgoto('OorM_<case_label>', 58) ->
 61;
yeccgoto('OorM_<definition>', 0) ->
 17;
yeccgoto('OorM_<definition>', 217) ->
 218;
yeccgoto('OorM_<fixed_array_size>', 171) ->
 174;
yeccgoto('OorM_<member>', 204) ->
 207;
yeccgoto('Opt_<context_expr>', 295) ->
 302;
yeccgoto('Opt_<inheritance_spec>', 221) ->
 224;
yeccgoto('Opt_<op_attribute>', 264) ->
 274;
yeccgoto('Opt_<raises_expr>', 293) ->
 295;
yeccgoto('Opt_readonly', 264) ->
 275;
yeccgoto('Ugly_pragmas', 54) ->
 58;
yeccgoto('Ugly_pragmas', 57) ->
 58;
yeccgoto('Ugly_pragmas', 58) ->
 62;
yeccgoto('Ugly_pragmas', 61) ->
 120;
yeccgoto('Ugly_pragmas', 63) ->
 119;
yeccgoto('Ugly_pragmas', 124) ->
 182;
yeccgoto('Ugly_pragmas', 127) ->
 179;
yeccgoto('Ugly_pragmas', 180) ->
 181;
yeccgoto('Ugly_pragmas', 204) ->
 208;
yeccgoto('Ugly_pragmas', 207) ->
 208;
yeccgoto('Ugly_pragmas', 210) ->
 211;
yeccgoto('Ugly_pragmas', 212) ->
 213;
yeccgoto('Ugly_pragmas', 230) ->
 231;
yeccgoto('Ugly_pragmas', 232) ->
 208;
yeccgoto('Ugly_pragmas', 236) ->
 237;
yeccgoto('Ugly_pragmas', 238) ->
 240;
yeccgoto('Ugly_pragmas', 241) ->
 242;
yeccgoto('Ugly_pragmas', 243) ->
 245;
yeccgoto('Ugly_pragmas', 292) ->
 310;
yeccgoto('Ugly_pragmas', 313) ->
 317;
yeccgoto('Ugly_pragmas', 318) ->
 320;
yeccgoto('Ugly_pragmas', 321) ->
 322;
yeccgoto('Ugly_pragmas', 323) ->
 324;
yeccgoto('ZorM_<declarator>', 198) ->
 200;
yeccgoto('ZorM_<enumerator>', 240) ->
 241;
yeccgoto('ZorM_<export>', 262) ->
 264;
yeccgoto('ZorM_<integer_literal>', 338) ->
 340;
yeccgoto('ZorM_<integer_literal>', 339) ->
 342;
yeccgoto('ZorM_<member>', 230) ->
 232;
yeccgoto('ZorM_<param_dcl>', 313) ->
 318;
yeccgoto('ZorM_<scoped_name>', 225) ->
 226;
yeccgoto('ZorM_<scoped_name>', 298) ->
 299;
yeccgoto('ZorM_<simple_declarator>', 284) ->
 285;
yeccgoto('ZorM_<string_literal>', 305) ->
 306;
yeccgoto(__Symbol, __State) ->
 exit({__Symbol, __State, missing_in_goto_table}).


