-module(megaco_text_parser_prev3a).
-define(THIS_MODULE, megaco_text_parser_prev3a).
-export([parse/1, parse_and_scan/1, format_error/1]).

%% The following directive is needed for (significantly) faster compilation
%% of the generated .erl file by the HiPE compiler.  Please do not remove.
-compile([{hipe,[{regalloc,linear_scan}]}]).

-include("megaco_text_parser_prev3a.hrl").



%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The parser generator will insert appropriate declarations before this line.%

parse(Tokens) ->
    case catch yeccpars1(Tokens, false, 0, [], []) of
	error ->
	    Errorline =
		if Tokens == [] -> 0; true -> element(2, hd(Tokens)) end,
	    {error,
	     {Errorline, ?THIS_MODULE, "syntax error at or after this line."}};
	Other ->
	    Other
    end.

parse_and_scan({Mod, Fun, Args}) ->
    case apply(Mod, Fun, Args) of
	{eof, _} ->
	    {ok, eof};
	{error, Descriptor, _} ->
	    {error, Descriptor};
	{ok, Tokens, _} ->
	    yeccpars1(Tokens, {Mod, Fun, Args}, 0, [], [])
    end.

format_error(Message) ->
    case io_lib:deep_char_list(Message) of
	true ->
	    Message;
	_ ->
	    io_lib:write(Message)
    end.

% To be used in grammar files to throw an error message to the parser toplevel.
% Doesn't have to be exported!
return_error(Line, Message) ->
    throw({error, {Line, ?THIS_MODULE, Message}}).


% Don't change yeccpars1/6 too much, it is called recursively by yeccpars2/8!
yeccpars1([Token | Tokens], Tokenizer, State, States, Vstack) ->
    yeccpars2(State, element(1, Token), States, Vstack, Token, Tokens,
	      Tokenizer);
yeccpars1([], {M, F, A}, State, States, Vstack) ->
    case catch apply(M, F, A) of
        {eof, _Endline} ->
            yeccpars1([], false, State, States, Vstack);
        {error, Descriptor, _Endline} ->
            {error, Descriptor};
        {'EXIT', Reason} ->
            {error, {0, ?THIS_MODULE, Reason}};
        {ok, Tokens, _Endline} ->
	    case catch yeccpars1(Tokens, {M, F, A}, State, States, Vstack) of
		error ->
		    Errorline = element(2, hd(Tokens)),
		    {error, {Errorline, ?THIS_MODULE,
			     "syntax error at or after this line."}};
		Other ->
		    Other
	    end
    end;
yeccpars1([], false, State, States, Vstack) ->
    yeccpars2(State, '$end', States, Vstack, {'$end', 999999}, [], false).

% For internal use only.
yeccerror(Token) ->
    {error,
     {element(2, Token), ?THIS_MODULE,
      ["syntax error before: ", yecctoken2string(Token)]}}.

yecctoken2string({atom, _, A}) -> io_lib:write(A);
yecctoken2string({integer,_,N}) -> io_lib:write(N);
yecctoken2string({float,_,F}) -> io_lib:write(F);
yecctoken2string({char,_,C}) -> io_lib:write_char(C);
yecctoken2string({var,_,V}) -> io_lib:format('~s', [V]);
yecctoken2string({string,_,S}) -> io_lib:write_string(S);
yecctoken2string({reserved_symbol, _, A}) -> io_lib:format('~w', [A]);
yecctoken2string({_Cat, _, Val}) -> io_lib:format('~w', [Val]);

yecctoken2string({'dot', _}) -> io_lib:format('~w', ['.']);
yecctoken2string({'$end', _}) ->
    [];
yecctoken2string({Other, _}) when atom(Other) ->
    io_lib:format('~w', [Other]);
yecctoken2string(Other) ->
    io_lib:write(Other).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


yeccpars2(0, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [0 | __Ss], [__T | __Stack]);
yeccpars2(0, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(3, __Cat, [0 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(1, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  sep,
 yeccpars2(yeccgoto(optSep, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(2, '$end', _, __Stack, _, _, _) ->
 {ok, hd(__Stack)};
yeccpars2(2, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(3, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 4, [3 | __Ss], [__T | __Stack]);
yeccpars2(3, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(5, __Cat, [3 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(4, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 886, [4 | __Ss], [__T | __Stack]);
yeccpars2(4, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(5, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [5 | __Ss], [__T | __Stack]);
yeccpars2(5, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(6, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(7, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(8, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(9, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(10, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(11, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(12, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(13, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(14, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(15, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(16, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(17, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(18, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(19, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(20, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(21, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(22, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(23, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(24, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(25, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(26, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(27, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(28, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(29, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(30, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(31, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(32, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(33, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(34, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(35, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(36, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(37, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(38, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(39, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(40, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(41, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(42, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(43, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(44, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(45, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(46, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(47, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(48, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(49, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(50, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(51, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(52, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(53, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(54, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(55, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(56, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(57, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(58, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(59, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(60, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(61, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(62, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(63, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(64, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(65, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(66, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(67, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(68, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(69, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(70, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(71, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(72, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(73, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(74, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(75, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(76, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(77, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(78, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(79, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(80, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(81, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(82, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(83, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(84, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(85, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(86, 'endOfMessage', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 885, [86 | __Ss], [__T | __Stack]);
yeccpars2(86, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(87, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 89, [87 | __Ss], [__T | __Stack]);
yeccpars2(87, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [87 | __Ss], [__T | __Stack]);
yeccpars2(87, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [87 | __Ss], [__T | __Stack]);
yeccpars2(87, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(93, __Cat, [87 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(88, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [88 | __Ss], [__T | __Stack]);
yeccpars2(88, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(89, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 871, [89 | __Ss], [__T | __Stack]);
yeccpars2(89, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(872, __Cat, [89 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(90, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(mId, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(91, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(mId, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(92, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [92 | __Ss], [__T | __Stack]);
yeccpars2(92, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 103, [92 | __Ss], [__T | __Stack]);
yeccpars2(92, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 105, [92 | __Ss], [__T | __Stack]);
yeccpars2(92, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 102, [92 | __Ss], [__T | __Stack]);
yeccpars2(92, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 104, [92 | __Ss], [__T | __Stack]);
yeccpars2(92, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(93, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, 'MtpAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 94, [93 | __Ss], [__T | __Stack]);
yeccpars2(93, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(94, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_mtpAddress(__1),
 yeccpars2(yeccgoto(mtpAddress, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(95, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [95 | __Ss], [__T | __Stack]);
yeccpars2(95, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(100, __Cat, [95 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(96, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [96 | __Ss], [__T | __Stack]);
yeccpars2(96, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(99, __Cat, [96 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(97, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {deviceName,__1},
 yeccpars2(yeccgoto(deviceName, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(98, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_pathName(__1),
 yeccpars2(yeccgoto(pathName, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(99, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(mId, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(100, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(mId, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(101, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 855, [101 | __Ss], [__T | __Stack]);
yeccpars2(101, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(102, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 867, [102 | __Ss], [__T | __Stack]);
yeccpars2(102, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(103, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 735, [103 | __Ss], [__T | __Stack]);
yeccpars2(103, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(104, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 727, [104 | __Ss], [__T | __Stack]);
yeccpars2(104, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(105, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 115, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 116, [105 | __Ss], [__T | __Stack]);
yeccpars2(105, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(106, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {messageError,__1},
 yeccpars2(yeccgoto(messageBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(107, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_message(__1,__2,__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(message, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(108, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 103, [108 | __Ss], [__T | __Stack]);
yeccpars2(108, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 105, [108 | __Ss], [__T | __Stack]);
yeccpars2(108, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 102, [108 | __Ss], [__T | __Stack]);
yeccpars2(108, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 104, [108 | __Ss], [__T | __Stack]);
yeccpars2(108, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1],
 yeccpars2(yeccgoto(transactionList, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(109, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactions,__1},
 yeccpars2(yeccgoto(messageBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(110, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactionPending,__1},
 yeccpars2(yeccgoto(transactionItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(111, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactionReply,__1},
 yeccpars2(yeccgoto(transactionItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(112, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactionRequest,__1},
 yeccpars2(yeccgoto(transactionItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(113, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactionResponseAck,__1},
 yeccpars2(yeccgoto(transactionItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(114, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(transactionList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(115, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 717, [115 | __Ss], [__T | __Stack]);
yeccpars2(115, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(116, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 117, [116 | __Ss], [__T | __Stack]);
yeccpars2(116, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(117, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 124, [117 | __Ss], [__T | __Stack]);
yeccpars2(117, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(118, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 119, [118 | __Ss], [__T | __Stack]);
yeccpars2(118, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(120, __Cat, [118 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(119, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 117, [119 | __Ss], [__T | __Stack]);
yeccpars2(119, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(120, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 121, [120 | __Ss], [__T | __Stack]);
yeccpars2(120, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(121, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TransactionRequest'{transactionId = asn1_NOVALUE, actions = [__3|__4]},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(transactionRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(122, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 119, [122 | __Ss], [__T | __Stack]);
yeccpars2(122, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(123, __Cat, [122 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(123, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(actionRequestList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(124, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [124 | __Ss], [__T | __Stack]);
yeccpars2(124, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(125, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 127, [125 | __Ss], [__T | __Stack]);
yeccpars2(125, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(126, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_contextID(__1),
 yeccpars2(yeccgoto(contextID, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(127, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 136, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 135, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 129, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 130, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'SubtractToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 137, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'ModifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 133, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'MoveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 134, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'AddToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 128, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 132, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, 'ContextAttrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 131, [127 | __Ss], [__T | __Stack]);
yeccpars2(127, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(128, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {addReq,__1},
 yeccpars2(yeccgoto(ammToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(129, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 714, [129 | __Ss], [__T | __Stack]);
yeccpars2(129, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(130, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 711, [130 | __Ss], [__T | __Stack]);
yeccpars2(130, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(131, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 676, [131 | __Ss], [__T | __Stack]);
yeccpars2(131, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(132, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 660, [132 | __Ss], [__T | __Stack]);
yeccpars2(132, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(133, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {modReq,__1},
 yeccpars2(yeccgoto(ammToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(134, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {moveReq,__1},
 yeccpars2(yeccgoto(ammToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(135, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 643, [135 | __Ss], [__T | __Stack]);
yeccpars2(135, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(136, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 593, [136 | __Ss], [__T | __Stack]);
yeccpars2(136, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(137, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 587, [137 | __Ss], [__T | __Stack]);
yeccpars2(137, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(138, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 586, [138 | __Ss], [__T | __Stack]);
yeccpars2(138, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(139, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 582, [139 | __Ss], [__T | __Stack]);
yeccpars2(139, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(583, __Cat, [139 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(140, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(commandRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(141, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 150, [141 | __Ss], [__T | __Stack]);
yeccpars2(141, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(142, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(commandRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(143, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {commandRequest,__1},
 yeccpars2(yeccgoto(actionRequestItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(144, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_context_request(#'ContextRequest'{},__1),
 yeccpars2(yeccgoto(contextProperties, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(145, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {contextAudit,__1},
 yeccpars2(yeccgoto(actionRequestItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(146, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {contextProps,__1},
 yeccpars2(yeccgoto(actionRequestItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(147, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(commandRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(148, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(commandRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(149, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(commandRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(150, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [150 | __Ss], [__T | __Stack]);
yeccpars2(150, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(151, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_terminationID(__1),
 yeccpars2(yeccgoto(terminationID, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(152, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 153, [152 | __Ss], [__T | __Stack]);
yeccpars2(152, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(154, __Cat, [152 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(153, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 160, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 158, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 161, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 159, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 155, [153 | __Ss], [__T | __Stack]);
yeccpars2(153, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(154, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val = begin
   Descs = merge_AmmRequest_descriptors(__4,[]), make_commandRequest(__1,#'AmmRequest'{terminationID = [__3], descriptors = Descs})
  end,
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(ammRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(155, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 476, [155 | __Ss], [__T | __Stack]);
yeccpars2(155, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(156, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_DMD(__1),
 yeccpars2(yeccgoto(digitMapDescriptor, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(157, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 450, [157 | __Ss], [__T | __Stack]);
yeccpars2(157, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(yeccgoto(eventBufferDescriptor, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(158, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 387, [158 | __Ss], [__T | __Stack]);
yeccpars2(158, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'EventsDescriptor'{requestID = asn1_NOVALUE, eventList = []},
 yeccpars2(yeccgoto(eventsDescriptor, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(159, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 316, [159 | __Ss], [__T | __Stack]);
yeccpars2(159, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(160, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 296, [160 | __Ss], [__T | __Stack]);
yeccpars2(160, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 295, [160 | __Ss], [__T | __Stack]);
yeccpars2(160, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(161, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 284, [161 | __Ss], [__T | __Stack]);
yeccpars2(161, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(162, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 192, [162 | __Ss], [__T | __Stack]);
yeccpars2(162, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(yeccgoto(signalsDescriptor, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(163, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 179, [163 | __Ss], [__T | __Stack]);
yeccpars2(163, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(164, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 174, [164 | __Ss], [__T | __Stack]);
yeccpars2(164, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(175, __Cat, [164 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(165, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(166, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {digitMapDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(167, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventBufferDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(168, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventsDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(169, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {mediaDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(170, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {modemDescriptor,deprecated},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(171, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {muxDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(172, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {signalsDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(173, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {statisticsDescriptor,__1},
 yeccpars2(yeccgoto(ammParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(174, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 160, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 158, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 161, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 159, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 155, [174 | __Ss], [__T | __Stack]);
yeccpars2(174, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(175, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 176, [175 | __Ss], [__T | __Stack]);
yeccpars2(175, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(176, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(ammRequestBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(177, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 174, [177 | __Ss], [__T | __Stack]);
yeccpars2(177, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(178, __Cat, [177 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(178, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(ammParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(179, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [179 | __Ss], [__T | __Stack]);
yeccpars2(179, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(180, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 188, [180 | __Ss], [__T | __Stack]);
yeccpars2(180, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'StatisticsParameter'{statName = __1, statValue = asn1_NOVALUE},
 yeccpars2(yeccgoto(statisticsParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(181, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_pkgdName(__1),
 yeccpars2(yeccgoto(pkgdName, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(182, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 183, [182 | __Ss], [__T | __Stack]);
yeccpars2(182, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(184, __Cat, [182 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(183, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [183 | __Ss], [__T | __Stack]);
yeccpars2(183, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(184, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 185, [184 | __Ss], [__T | __Stack]);
yeccpars2(184, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(185, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(statisticsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(186, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 183, [186 | __Ss], [__T | __Stack]);
yeccpars2(186, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(187, __Cat, [186 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(187, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(statisticsParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(188, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [188 | __Ss], [__T | __Stack]);
yeccpars2(188, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(189, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_value(__1),
 yeccpars2(yeccgoto(value, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(190, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_value(__1),
 yeccpars2(yeccgoto(value, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(191, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'StatisticsParameter'{statName = __1, statValue = [__3]},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(statisticsParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(192, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 193, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [192 | __Ss], [__T | __Stack]);
yeccpars2(192, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(193, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 273, [193 | __Ss], [__T | __Stack]);
yeccpars2(193, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(194, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(signalName, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(195, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {seqSigList,__1},
 yeccpars2(yeccgoto(signalParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(196, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 204, [196 | __Ss], [__T | __Stack]);
yeccpars2(196, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_signalRequest(__1,[]),
 yeccpars2(yeccgoto(signalRequest, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(197, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 199, [197 | __Ss], [__T | __Stack]);
yeccpars2(197, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(200, __Cat, [197 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(198, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {signal,__1},
 yeccpars2(yeccgoto(signalParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(199, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 193, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [199 | __Ss], [__T | __Stack]);
yeccpars2(199, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(200, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 201, [200 | __Ss], [__T | __Stack]);
yeccpars2(200, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(201, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(signalsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(202, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 199, [202 | __Ss], [__T | __Stack]);
yeccpars2(202, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(203, __Cat, [202 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(203, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(signalParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(204, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 211, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 210, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 209, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 208, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 207, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 206, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 205, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [204 | __Ss], [__T | __Stack]);
yeccpars2(204, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(205, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 268, [205 | __Ss], [__T | __Stack]);
yeccpars2(205, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(206, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 266, [206 | __Ss], [__T | __Stack]);
yeccpars2(206, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(207, 'COMMA', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(sigParameter, hd(__Ss)), 'COMMA', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(207, 'RBRKT', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(sigParameter, hd(__Ss)), 'RBRKT', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(207, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(208, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 254, [208 | __Ss], [__T | __Stack]);
yeccpars2(208, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(209, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 251, [209 | __Ss], [__T | __Stack]);
yeccpars2(209, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(210, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 246, [210 | __Ss], [__T | __Stack]);
yeccpars2(210, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(211, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 243, [211 | __Ss], [__T | __Stack]);
yeccpars2(211, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(212, 'GREATER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 220, [212 | __Ss], [__T | __Stack]);
yeccpars2(212, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 221, [212 | __Ss], [__T | __Stack]);
yeccpars2(212, 'NEQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 222, [212 | __Ss], [__T | __Stack]);
yeccpars2(212, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 219, [212 | __Ss], [__T | __Stack]);
yeccpars2(212, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(213, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 214, [213 | __Ss], [__T | __Stack]);
yeccpars2(213, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(215, __Cat, [213 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(214, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 211, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 210, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 209, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 208, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 207, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 206, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 205, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [214 | __Ss], [__T | __Stack]);
yeccpars2(214, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(215, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 216, [215 | __Ss], [__T | __Stack]);
yeccpars2(215, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(216, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_signalRequest(__1,[__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(signalRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(217, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 214, [217 | __Ss], [__T | __Stack]);
yeccpars2(217, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(218, __Cat, [217 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(218, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(219, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 228, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 227, [219 | __Ss], [__T | __Stack]);
yeccpars2(219, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(220, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [220 | __Ss], [__T | __Stack]);
yeccpars2(220, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(221, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [221 | __Ss], [__T | __Stack]);
yeccpars2(221, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(222, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [222 | __Ss], [__T | __Stack]);
yeccpars2(222, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(223, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {other,ensure_NAME(__1),__2},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(224, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2], extraInfo = {relation,unequalTo}},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(parmValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(225, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2], extraInfo = {relation,smallerThan}},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(parmValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(226, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2], extraInfo = {relation,greaterThan}},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(parmValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(227, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [227 | __Ss], [__T | __Stack]);
yeccpars2(227, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(228, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [228 | __Ss], [__T | __Stack]);
yeccpars2(228, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(229, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(parmValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(230, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__1]},
 yeccpars2(yeccgoto(alternativeValue, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(231, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 233, [231 | __Ss], [__T | __Stack]);
yeccpars2(231, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 232, [231 | __Ss], [__T | __Stack]);
yeccpars2(231, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(234, __Cat, [231 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(232, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [232 | __Ss], [__T | __Stack]);
yeccpars2(232, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(233, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [233 | __Ss], [__T | __Stack]);
yeccpars2(233, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(234, 'RSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 235, [234 | __Ss], [__T | __Stack]);
yeccpars2(234, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(235, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2|__3], extraInfo = {sublist,true}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(alternativeValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(236, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 233, [236 | __Ss], [__T | __Stack]);
yeccpars2(236, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(237, __Cat, [236 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(237, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(valueList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(238, 'RSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 239, [238 | __Ss], [__T | __Stack]);
yeccpars2(238, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(239, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2,__4], extraInfo = {range,true}},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(alternativeValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(240, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 233, [240 | __Ss], [__T | __Stack]);
yeccpars2(240, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(241, __Cat, [240 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(241, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 242, [241 | __Ss], [__T | __Stack]);
yeccpars2(241, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(242, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'PropertyParm'{value = [__2|__3], extraInfo = {sublist,false}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(alternativeValue, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(243, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [243 | __Ss], [__T | __Stack]);
yeccpars2(243, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(244, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_streamID(__1),
 yeccpars2(yeccgoto(streamID, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(245, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {stream,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(246, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 247, [246 | __Ss], [__T | __Stack]);
yeccpars2(246, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 249, [246 | __Ss], [__T | __Stack]);
yeccpars2(246, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 248, [246 | __Ss], [__T | __Stack]);
yeccpars2(246, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(247, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  brief,
 yeccpars2(yeccgoto(signalType, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(248, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  onOff,
 yeccpars2(yeccgoto(signalType, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(249, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  timeOut,
 yeccpars2(yeccgoto(signalType, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(250, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {signal_type,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(251, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [251 | __Ss], [__T | __Stack]);
yeccpars2(251, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(252, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {requestId,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(253, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_requestID(__1),
 yeccpars2(yeccgoto(requestID, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(254, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 255, [254 | __Ss], [__T | __Stack]);
yeccpars2(254, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(255, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 258, [255 | __Ss], [__T | __Stack]);
yeccpars2(255, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 257, [255 | __Ss], [__T | __Stack]);
yeccpars2(255, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 256, [255 | __Ss], [__T | __Stack]);
yeccpars2(255, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 259, [255 | __Ss], [__T | __Stack]);
yeccpars2(255, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(256, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  onInterruptByEvent,
 yeccpars2(yeccgoto(notificationReason, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(257, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  onInterruptByNewSignalDescr,
 yeccpars2(yeccgoto(notificationReason, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(258, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  otherReason,
 yeccpars2(yeccgoto(notificationReason, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(259, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  onTimeOut,
 yeccpars2(yeccgoto(notificationReason, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(260, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 261, [260 | __Ss], [__T | __Stack]);
yeccpars2(260, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(262, __Cat, [260 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(261, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 258, [261 | __Ss], [__T | __Stack]);
yeccpars2(261, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 257, [261 | __Ss], [__T | __Stack]);
yeccpars2(261, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 256, [261 | __Ss], [__T | __Stack]);
yeccpars2(261, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 259, [261 | __Ss], [__T | __Stack]);
yeccpars2(261, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(262, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 263, [262 | __Ss], [__T | __Stack]);
yeccpars2(262, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(263, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {notify_completion,[__4|__5]},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(264, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 261, [264 | __Ss], [__T | __Stack]);
yeccpars2(264, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(265, __Cat, [264 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(265, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(notificationReasons, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(266, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [266 | __Ss], [__T | __Stack]);
yeccpars2(266, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(267, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {duration,ensure_uint16(__3)},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(268, 'BothToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 269, [268 | __Ss], [__T | __Stack]);
yeccpars2(268, 'InternalToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 271, [268 | __Ss], [__T | __Stack]);
yeccpars2(268, 'ExternalToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 270, [268 | __Ss], [__T | __Stack]);
yeccpars2(268, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(269, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  both,
 yeccpars2(yeccgoto(direction, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(270, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  external,
 yeccpars2(yeccgoto(direction, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(271, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  internal,
 yeccpars2(yeccgoto(direction, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(272, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {direction,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(sigParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(273, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [273 | __Ss], [__T | __Stack]);
yeccpars2(273, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(274, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint16(__1),
 yeccpars2(yeccgoto(signalListId, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(275, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 276, [275 | __Ss], [__T | __Stack]);
yeccpars2(275, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(276, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [276 | __Ss], [__T | __Stack]);
yeccpars2(276, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(277, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 279, [277 | __Ss], [__T | __Stack]);
yeccpars2(277, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(280, __Cat, [277 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(278, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(signalListParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(279, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [279 | __Ss], [__T | __Stack]);
yeccpars2(279, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(280, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 281, [280 | __Ss], [__T | __Stack]);
yeccpars2(280, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(281, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'SeqSigList'{id = ensure_uint16(__3), signalList = [__5|__6]},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(signalList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(282, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 279, [282 | __Ss], [__T | __Stack]);
yeccpars2(282, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(283, __Cat, [282 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(283, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(signalListParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(284, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [284 | __Ss], [__T | __Stack]);
yeccpars2(284, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(285, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 287, [285 | __Ss], [__T | __Stack]);
yeccpars2(285, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(286, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_muxType(__1),
 yeccpars2(yeccgoto(muxType, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(287, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [287 | __Ss], [__T | __Stack]);
yeccpars2(287, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(288, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'MuxDescriptor'{muxType = __3, termList = __4},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(muxDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(289, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 290, [289 | __Ss], [__T | __Stack]);
yeccpars2(289, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(291, __Cat, [289 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(290, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [290 | __Ss], [__T | __Stack]);
yeccpars2(290, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(291, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 292, [291 | __Ss], [__T | __Stack]);
yeccpars2(291, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(292, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(terminationIDList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(293, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 290, [293 | __Ss], [__T | __Stack]);
yeccpars2(293, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(294, __Cat, [293 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(294, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(terminationIDListRepeat, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(295, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [295 | __Ss], [__T | __Stack]);
yeccpars2(295, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(296, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [296 | __Ss], [__T | __Stack]);
yeccpars2(296, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(297, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 299, [297 | __Ss], [__T | __Stack]);
yeccpars2(297, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 yeccpars2(300, __Cat, [297 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(298, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 yeccpars2(yeccgoto(modemType, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(299, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [299 | __Ss], [__T | __Stack]);
yeccpars2(299, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(300, 'RSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 301, [300 | __Ss], [__T | __Stack]);
yeccpars2(300, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(301, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 302, [301 | __Ss], [__T | __Stack]);
yeccpars2(301, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(303, __Cat, [301 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(302, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [302 | __Ss], [__T | __Stack]);
yeccpars2(302, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(303, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(modemDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(304, 'GREATER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 220, [304 | __Ss], [__T | __Stack]);
yeccpars2(304, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 221, [304 | __Ss], [__T | __Stack]);
yeccpars2(304, 'NEQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 222, [304 | __Ss], [__T | __Stack]);
yeccpars2(304, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 219, [304 | __Ss], [__T | __Stack]);
yeccpars2(304, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(305, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 306, [305 | __Ss], [__T | __Stack]);
yeccpars2(305, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(307, __Cat, [305 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(306, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [306 | __Ss], [__T | __Stack]);
yeccpars2(306, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(307, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 308, [307 | __Ss], [__T | __Stack]);
yeccpars2(307, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(308, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(optPropertyParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(309, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 306, [309 | __Ss], [__T | __Stack]);
yeccpars2(309, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(310, __Cat, [309 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(310, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(propertyParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(311, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  setelement(#'PropertyParm'.name,__2,__1),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(propertyParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(312, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 299, [312 | __Ss], [__T | __Stack]);
yeccpars2(312, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 yeccpars2(313, __Cat, [312 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(313, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(modemTypeList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(314, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 302, [314 | __Ss], [__T | __Stack]);
yeccpars2(314, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(315, __Cat, [314 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(315, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(modemDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(316, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 321, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 317, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 320, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, 'RemoteDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 319, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, 'LocalDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 318, [316 | __Ss], [__T | __Stack]);
yeccpars2(316, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(317, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 363, [317 | __Ss], [__T | __Stack]);
yeccpars2(317, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(318, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {local,#'LocalRemoteDescriptor'{propGrps = ensure_prop_groups(__1)}},
 yeccpars2(yeccgoto(streamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(319, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {remote,#'LocalRemoteDescriptor'{propGrps = ensure_prop_groups(__1)}},
 yeccpars2(yeccgoto(streamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(320, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 354, [320 | __Ss], [__T | __Stack]);
yeccpars2(320, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(321, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 333, [321 | __Ss], [__T | __Stack]);
yeccpars2(321, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(322, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {control,__1},
 yeccpars2(yeccgoto(streamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(323, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 328, [323 | __Ss], [__T | __Stack]);
yeccpars2(323, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(329, __Cat, [323 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(324, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {statistics,__1},
 yeccpars2(yeccgoto(streamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(325, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {streamDescriptor,__1},
 yeccpars2(yeccgoto(mediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(326, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {streamParm,__1},
 yeccpars2(yeccgoto(mediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(327, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {termState,__1},
 yeccpars2(yeccgoto(mediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(328, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 321, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 317, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 320, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, 'RemoteDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 319, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, 'LocalDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 318, [328 | __Ss], [__T | __Stack]);
yeccpars2(328, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(329, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 330, [329 | __Ss], [__T | __Stack]);
yeccpars2(329, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(330, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_mediaDescriptor([__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(mediaDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(331, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 328, [331 | __Ss], [__T | __Stack]);
yeccpars2(331, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(332, __Cat, [331 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(332, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(mediaParmList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(333, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 335, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 334, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [333 | __Ss], [__T | __Stack]);
yeccpars2(333, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(334, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 350, [334 | __Ss], [__T | __Stack]);
yeccpars2(334, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(335, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 345, [335 | __Ss], [__T | __Stack]);
yeccpars2(335, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(336, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventBufferControl,__1},
 yeccpars2(yeccgoto(terminationStateParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(337, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {propertyParm,__1},
 yeccpars2(yeccgoto(terminationStateParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(338, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {serviceState,__1},
 yeccpars2(yeccgoto(terminationStateParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(339, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 340, [339 | __Ss], [__T | __Stack]);
yeccpars2(339, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(341, __Cat, [339 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(340, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 335, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 334, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [340 | __Ss], [__T | __Stack]);
yeccpars2(340, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(341, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 342, [341 | __Ss], [__T | __Stack]);
yeccpars2(341, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(342, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_terminationStateDescriptor([__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(terminationStateDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(343, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 340, [343 | __Ss], [__T | __Stack]);
yeccpars2(343, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(344, __Cat, [343 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(344, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(terminationStateParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(345, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 346, [345 | __Ss], [__T | __Stack]);
yeccpars2(345, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 347, [345 | __Ss], [__T | __Stack]);
yeccpars2(345, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 348, [345 | __Ss], [__T | __Stack]);
yeccpars2(345, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(346, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  inSvc,
 yeccpars2(yeccgoto(serviceState, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(347, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  outOfSvc,
 yeccpars2(yeccgoto(serviceState, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(348, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  test,
 yeccpars2(yeccgoto(serviceState, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(349, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceStates, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(350, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 351, [350 | __Ss], [__T | __Stack]);
yeccpars2(350, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 352, [350 | __Ss], [__T | __Stack]);
yeccpars2(350, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(351, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  lockStep,
 yeccpars2(yeccgoto(eventBufferControlState, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(352, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  off,
 yeccpars2(yeccgoto(eventBufferControlState, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(353, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(eventBufferControl, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(354, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [354 | __Ss], [__T | __Stack]);
yeccpars2(354, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(355, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 356, [355 | __Ss], [__T | __Stack]);
yeccpars2(355, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(356, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [356 | __Ss], [__T | __Stack]);
yeccpars2(356, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 317, [356 | __Ss], [__T | __Stack]);
yeccpars2(356, 'RemoteDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 319, [356 | __Ss], [__T | __Stack]);
yeccpars2(356, 'LocalDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 318, [356 | __Ss], [__T | __Stack]);
yeccpars2(356, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(357, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 358, [357 | __Ss], [__T | __Stack]);
yeccpars2(357, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(359, __Cat, [357 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(358, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 163, [358 | __Ss], [__T | __Stack]);
yeccpars2(358, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 317, [358 | __Ss], [__T | __Stack]);
yeccpars2(358, 'RemoteDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 319, [358 | __Ss], [__T | __Stack]);
yeccpars2(358, 'LocalDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 318, [358 | __Ss], [__T | __Stack]);
yeccpars2(358, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(359, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 360, [359 | __Ss], [__T | __Stack]);
yeccpars2(359, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(360, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'StreamDescriptor'{streamID = __3, streamParms = merge_streamParms([__5|__6])},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(streamDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(361, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 358, [361 | __Ss], [__T | __Stack]);
yeccpars2(361, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(362, __Cat, [361 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(362, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(streamParmList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(363, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 366, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 365, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 364, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [363 | __Ss], [__T | __Stack]);
yeccpars2(363, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(364, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 380, [364 | __Ss], [__T | __Stack]);
yeccpars2(364, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(365, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 378, [365 | __Ss], [__T | __Stack]);
yeccpars2(365, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(366, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 374, [366 | __Ss], [__T | __Stack]);
yeccpars2(366, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(367, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 369, [367 | __Ss], [__T | __Stack]);
yeccpars2(367, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(370, __Cat, [367 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(368, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {prop,__1},
 yeccpars2(yeccgoto(localParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(369, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 366, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 365, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 364, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [369 | __Ss], [__T | __Stack]);
yeccpars2(369, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(370, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 371, [370 | __Ss], [__T | __Stack]);
yeccpars2(370, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(371, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(localControlDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(372, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 369, [372 | __Ss], [__T | __Stack]);
yeccpars2(372, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(373, __Cat, [372 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(373, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(localParmList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(374, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 375, [374 | __Ss], [__T | __Stack]);
yeccpars2(374, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 376, [374 | __Ss], [__T | __Stack]);
yeccpars2(374, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(375, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  false,
 yeccpars2(yeccgoto(onOrOff, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(376, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  true,
 yeccpars2(yeccgoto(onOrOff, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(377, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {value,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(localParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(378, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 375, [378 | __Ss], [__T | __Stack]);
yeccpars2(378, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 376, [378 | __Ss], [__T | __Stack]);
yeccpars2(378, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(379, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {group,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(localParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(380, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 382, [380 | __Ss], [__T | __Stack]);
yeccpars2(380, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 381, [380 | __Ss], [__T | __Stack]);
yeccpars2(380, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 385, [380 | __Ss], [__T | __Stack]);
yeccpars2(380, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 383, [380 | __Ss], [__T | __Stack]);
yeccpars2(380, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 384, [380 | __Ss], [__T | __Stack]);
yeccpars2(380, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(381, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  inactive,
 yeccpars2(yeccgoto(streamModes, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(382, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  loopBack,
 yeccpars2(yeccgoto(streamModes, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(383, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  recvOnly,
 yeccpars2(yeccgoto(streamModes, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(384, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  sendOnly,
 yeccpars2(yeccgoto(streamModes, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(385, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  sendRecv,
 yeccpars2(yeccgoto(streamModes, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(386, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {mode,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(localParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(387, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [387 | __Ss], [__T | __Stack]);
yeccpars2(387, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(388, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 389, [388 | __Ss], [__T | __Stack]);
yeccpars2(388, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(389, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [389 | __Ss], [__T | __Stack]);
yeccpars2(389, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(390, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 397, [390 | __Ss], [__T | __Stack]);
yeccpars2(390, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  #'RequestedEvent'{evParList = []},
 yeccpars2(398, __Cat, [390 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(391, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 392, [391 | __Ss], [__T | __Stack]);
yeccpars2(391, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(393, __Cat, [391 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(392, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [392 | __Ss], [__T | __Stack]);
yeccpars2(392, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(393, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 394, [393 | __Ss], [__T | __Stack]);
yeccpars2(393, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(394, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'EventsDescriptor'{requestID = __3, eventList = [__5|__6]},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(eventsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(395, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 392, [395 | __Ss], [__T | __Stack]);
yeccpars2(395, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(396, __Cat, [395 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(396, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(requestedEvents, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(397, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 401, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 400, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 399, [397 | __Ss], [__T | __Stack]);
yeccpars2(397, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(398, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  setelement(#'RequestedEvent'.pkgdName,__2,__1),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(requestedEvent, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(399, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_eventDM(__1),
 yeccpars2(yeccgoto(eventDM, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(400, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 415, [400 | __Ss], [__T | __Stack]);
yeccpars2(400, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(401, 'COMMA', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), 'COMMA', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(401, 'RBRKT', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), 'RBRKT', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(401, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(402, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(403, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(404, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(405, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 410, [405 | __Ss], [__T | __Stack]);
yeccpars2(405, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(411, __Cat, [405 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(406, 'GREATER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 220, [406 | __Ss], [__T | __Stack]);
yeccpars2(406, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 221, [406 | __Ss], [__T | __Stack]);
yeccpars2(406, 'NEQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 222, [406 | __Ss], [__T | __Stack]);
yeccpars2(406, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 219, [406 | __Ss], [__T | __Stack]);
yeccpars2(406, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(407, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(eventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(408, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_NAME(__1),
 yeccpars2(yeccgoto(eventParameterName, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(409, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  select_stream_or_other(__1,__2),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(eventStreamOrOther, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(410, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 401, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 400, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 399, [410 | __Ss], [__T | __Stack]);
yeccpars2(410, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(411, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 412, [411 | __Ss], [__T | __Stack]);
yeccpars2(411, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(412, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_eventParameters([__2|__3]),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(requestedEventBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(413, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 410, [413 | __Ss], [__T | __Stack]);
yeccpars2(413, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(414, __Cat, [413 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(414, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(eventParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(415, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [415 | __Ss], [__T | __Stack]);
yeccpars2(415, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 416, [415 | __Ss], [__T | __Stack]);
yeccpars2(415, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(416, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 424, [416 | __Ss], [__T | __Stack]);
yeccpars2(416, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'SecondEventsDescriptor'{requestID = asn1_NOVALUE, eventList = []},
 yeccpars2(yeccgoto(embedFirst, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(417, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 423, [417 | __Ss], [__T | __Stack]);
yeccpars2(417, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(418, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 420, [418 | __Ss], [__T | __Stack]);
yeccpars2(418, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 419, [418 | __Ss], [__T | __Stack]);
yeccpars2(418, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(419, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 416, [419 | __Ss], [__T | __Stack]);
yeccpars2(419, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(420, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {embed,__3,asn1_NOVALUE},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(embedWithSig, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(421, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 422, [421 | __Ss], [__T | __Stack]);
yeccpars2(421, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(422, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {embed,__3,__5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(embedWithSig, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(423, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {embed,asn1_NOVALUE,__3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(embedNoSig, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(424, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [424 | __Ss], [__T | __Stack]);
yeccpars2(424, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(425, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 426, [425 | __Ss], [__T | __Stack]);
yeccpars2(425, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(426, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [426 | __Ss], [__T | __Stack]);
yeccpars2(426, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(427, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 434, [427 | __Ss], [__T | __Stack]);
yeccpars2(427, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  #'SecondRequestedEvent'{evParList = []},
 yeccpars2(435, __Cat, [427 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(428, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 429, [428 | __Ss], [__T | __Stack]);
yeccpars2(428, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(430, __Cat, [428 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(429, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [429 | __Ss], [__T | __Stack]);
yeccpars2(429, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(430, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 431, [430 | __Ss], [__T | __Stack]);
yeccpars2(430, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(431, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'SecondEventsDescriptor'{requestID = __3, eventList = [__5|__6]},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(embedFirst, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(432, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 429, [432 | __Ss], [__T | __Stack]);
yeccpars2(432, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(433, __Cat, [432 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(433, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(secondRequestedEvents, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(434, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 437, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 436, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 399, [434 | __Ss], [__T | __Stack]);
yeccpars2(434, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(435, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  setelement(#'SecondRequestedEvent'.pkgdName,__2,__1),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(secondRequestedEvent, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(436, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 447, [436 | __Ss], [__T | __Stack]);
yeccpars2(436, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(437, 'COMMA', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(secondEventParameter, hd(__Ss)), 'COMMA', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(437, 'RBRKT', __Ss, [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  keepActive,
 yeccpars2(yeccgoto(secondEventParameter, hd(__Ss)), 'RBRKT', __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(437, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(438, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(secondEventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(439, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(secondEventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(440, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(secondEventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(441, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 442, [441 | __Ss], [__T | __Stack]);
yeccpars2(441, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(443, __Cat, [441 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(442, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 437, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 436, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 399, [442 | __Ss], [__T | __Stack]);
yeccpars2(442, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(443, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 444, [443 | __Ss], [__T | __Stack]);
yeccpars2(443, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(444, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_secondEventParameters([__2|__3]),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(secondRequestedEventBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(445, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 442, [445 | __Ss], [__T | __Stack]);
yeccpars2(445, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(446, __Cat, [445 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(446, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(secondEventParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(447, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [447 | __Ss], [__T | __Stack]);
yeccpars2(447, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(448, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 449, [448 | __Ss], [__T | __Stack]);
yeccpars2(448, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(449, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {second_embed,__3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(embedSig, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(450, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [450 | __Ss], [__T | __Stack]);
yeccpars2(450, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [450 | __Ss], [__T | __Stack]);
yeccpars2(450, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(454, __Cat, [450 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(451, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_timeStamp(__1),
 yeccpars2(yeccgoto(timeStamp, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(452, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 471, [452 | __Ss], [__T | __Stack]);
yeccpars2(452, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(472, __Cat, [452 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(453, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_eventSpec(__1),
 yeccpars2(yeccgoto(eventSpec, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(454, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [454 | __Ss], [__T | __Stack]);
yeccpars2(454, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(455, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [455 | __Ss], [__T | __Stack]);
yeccpars2(455, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(456, __Cat, [455 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(456, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 457, [456 | __Ss], [__T | __Stack]);
yeccpars2(456, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(457, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [457 | __Ss], [__T | __Stack]);
yeccpars2(457, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(458, __Cat, [457 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(458, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [458 | __Ss], [__T | __Stack]);
yeccpars2(458, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(459, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 460, [459 | __Ss], [__T | __Stack]);
yeccpars2(459, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(461, __Cat, [459 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(460, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [460 | __Ss], [__T | __Stack]);
yeccpars2(460, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(461, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_observed_event(__6,__5,__1),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(observedEvent, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(462, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(observedEventParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(463, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 464, [463 | __Ss], [__T | __Stack]);
yeccpars2(463, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(465, __Cat, [463 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(464, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [464 | __Ss], [__T | __Stack]);
yeccpars2(464, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(465, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 466, [465 | __Ss], [__T | __Stack]);
yeccpars2(465, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(466, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(observedEventBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(467, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 464, [467 | __Ss], [__T | __Stack]);
yeccpars2(467, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(468, __Cat, [467 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(468, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(observedEventParameters, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(469, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 460, [469 | __Ss], [__T | __Stack]);
yeccpars2(469, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(470, __Cat, [469 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(470, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_observed_event(__3,__2,asn1_NOVALUE),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(observedEvent, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(471, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [471 | __Ss], [__T | __Stack]);
yeccpars2(471, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [471 | __Ss], [__T | __Stack]);
yeccpars2(471, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(454, __Cat, [471 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(472, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 473, [472 | __Ss], [__T | __Stack]);
yeccpars2(472, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(473, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(eventBufferDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(474, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 471, [474 | __Ss], [__T | __Stack]);
yeccpars2(474, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(475, __Cat, [474 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(475, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(eventSpecList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(476, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 485, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 487, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 477, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 486, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 480, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 479, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 481, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 484, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 482, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 483, [476 | __Ss], [__T | __Stack]);
yeccpars2(476, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(488, __Cat, [476 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(477, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_IADMD(__1),
 yeccpars2(yeccgoto(indAuddigitMapDescriptor, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(478, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  digitMapToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(479, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 564, [479 | __Ss], [__T | __Stack]);
yeccpars2(479, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  eventBufferToken,
 yeccpars2(yeccgoto(auditItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(480, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 558, [480 | __Ss], [__T | __Stack]);
yeccpars2(480, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  eventsToken,
 yeccpars2(yeccgoto(auditItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(481, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 530, [481 | __Ss], [__T | __Stack]);
yeccpars2(481, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  mediaToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(482, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  modemToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(483, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  muxToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(484, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  observedEventsToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(485, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 526, [485 | __Ss], [__T | __Stack]);
yeccpars2(485, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  packagesToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(486, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 513, [486 | __Ss], [__T | __Stack]);
yeccpars2(486, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  signalsToken,
 yeccpars2(yeccgoto(auditItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(487, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 510, [487 | __Ss], [__T | __Stack]);
yeccpars2(487, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  statsToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(488, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 581, [488 | __Ss], [__T | __Stack]);
yeccpars2(488, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(489, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 577, [489 | __Ss], [__T | __Stack]);
yeccpars2(489, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(578, __Cat, [489 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(490, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(auditItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(491, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 500, [491 | __Ss], [__T | __Stack]);
yeccpars2(491, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(501, __Cat, [491 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(492, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudDigitMapDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(493, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudEventBufferDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(494, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudEventsDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(495, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudMediaDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(496, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudPackagesDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(497, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudSignalsDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(498, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {indAudStatisticsDescriptor,__1},
 yeccpars2(yeccgoto(indAudauditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(499, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {terminationAudit,__1},
 yeccpars2(yeccgoto(auditItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(500, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 505, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 507, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 477, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 506, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 503, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 502, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 504, [500 | __Ss], [__T | __Stack]);
yeccpars2(500, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(501, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(indAudterminationAudit, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(502, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 564, [502 | __Ss], [__T | __Stack]);
yeccpars2(502, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(503, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 558, [503 | __Ss], [__T | __Stack]);
yeccpars2(503, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(504, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 530, [504 | __Ss], [__T | __Stack]);
yeccpars2(504, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(505, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 526, [505 | __Ss], [__T | __Stack]);
yeccpars2(505, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(506, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 513, [506 | __Ss], [__T | __Stack]);
yeccpars2(506, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(507, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 510, [507 | __Ss], [__T | __Stack]);
yeccpars2(507, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(508, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 500, [508 | __Ss], [__T | __Stack]);
yeccpars2(508, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(509, __Cat, [508 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(509, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(indAudterminationAuditList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(510, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [510 | __Ss], [__T | __Stack]);
yeccpars2(510, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(511, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 512, [511 | __Ss], [__T | __Stack]);
yeccpars2(511, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(512, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudStatisticsDescriptor'{statName = __3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(indAudstatisticsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(513, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 516, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 515, [513 | __Ss], [__T | __Stack]);
yeccpars2(513, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(514, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(indAudsignalsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(515, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(optIndAudsignalParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(516, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 521, [516 | __Ss], [__T | __Stack]);
yeccpars2(516, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(517, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {seqSigList,__1},
 yeccpars2(yeccgoto(indAudsignalParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(518, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 520, [518 | __Ss], [__T | __Stack]);
yeccpars2(518, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(519, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {signal,ensure_indAudSignal(__1)},
 yeccpars2(yeccgoto(indAudsignalParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(520, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(optIndAudsignalParm, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(521, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [521 | __Ss], [__T | __Stack]);
yeccpars2(521, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(522, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 523, [522 | __Ss], [__T | __Stack]);
yeccpars2(522, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(523, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [523 | __Ss], [__T | __Stack]);
yeccpars2(523, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(524, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 525, [524 | __Ss], [__T | __Stack]);
yeccpars2(524, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(525, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudSeqSigList'{id = ensure_uint16(__3), signalList = ensure_indAudSignalListParm(__5)},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(indAudsignalList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(526, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [526 | __Ss], [__T | __Stack]);
yeccpars2(526, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(527, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 529, [527 | __Ss], [__T | __Stack]);
yeccpars2(527, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(528, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_packagesItem(__1),
 yeccpars2(yeccgoto(packagesItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(529, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_indAudPackagesDescriptor(__3),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(indAudpackagesDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(530, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 507, [530 | __Ss], [__T | __Stack]);
yeccpars2(530, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 533, [530 | __Ss], [__T | __Stack]);
yeccpars2(530, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 531, [530 | __Ss], [__T | __Stack]);
yeccpars2(530, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 532, [530 | __Ss], [__T | __Stack]);
yeccpars2(530, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(531, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 550, [531 | __Ss], [__T | __Stack]);
yeccpars2(531, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(532, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 545, [532 | __Ss], [__T | __Stack]);
yeccpars2(532, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(533, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 541, [533 | __Ss], [__T | __Stack]);
yeccpars2(533, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(534, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudStreamParms'{localControlDescriptor = __1},
 yeccpars2(yeccgoto(indAudstreamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(535, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 540, [535 | __Ss], [__T | __Stack]);
yeccpars2(535, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(536, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudStreamParms'{statisticsDescriptor = __1},
 yeccpars2(yeccgoto(indAudstreamParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(537, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {streamDescr,__1},
 yeccpars2(yeccgoto(indAudmediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(538, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {streamParm,__1},
 yeccpars2(yeccgoto(indAudmediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(539, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {termStateDescr,__1},
 yeccpars2(yeccgoto(indAudmediaParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(540, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_indAudMediaDescriptor(__3),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(indAudmediaDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(541, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [541 | __Ss], [__T | __Stack]);
yeccpars2(541, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(542, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 544, [542 | __Ss], [__T | __Stack]);
yeccpars2(542, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(543, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_indAudTerminationStateParm(__1),
 yeccpars2(yeccgoto(indAudterminationStateParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(544, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_indAudTerminationStateDescriptor(__3),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(indAudterminationStateDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(545, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [545 | __Ss], [__T | __Stack]);
yeccpars2(545, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(546, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 547, [546 | __Ss], [__T | __Stack]);
yeccpars2(546, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(547, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 507, [547 | __Ss], [__T | __Stack]);
yeccpars2(547, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 531, [547 | __Ss], [__T | __Stack]);
yeccpars2(547, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(548, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 549, [548 | __Ss], [__T | __Stack]);
yeccpars2(548, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(549, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudStreamDescriptor'{streamID = __3, streamParms = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(indAudstreamDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(550, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [550 | __Ss], [__T | __Stack]);
yeccpars2(550, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(551, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 553, [551 | __Ss], [__T | __Stack]);
yeccpars2(551, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(554, __Cat, [551 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(552, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_indAudLocalParm(__1),
 yeccpars2(yeccgoto(indAudlocalParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(553, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [553 | __Ss], [__T | __Stack]);
yeccpars2(553, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(554, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 555, [554 | __Ss], [__T | __Stack]);
yeccpars2(554, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(555, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_indAudLocalControlDescriptor([__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(indAudlocalControlDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(556, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 553, [556 | __Ss], [__T | __Stack]);
yeccpars2(556, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(557, __Cat, [556 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(557, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(indAudlocalParmList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(558, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [558 | __Ss], [__T | __Stack]);
yeccpars2(558, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(559, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 560, [559 | __Ss], [__T | __Stack]);
yeccpars2(559, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(560, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [560 | __Ss], [__T | __Stack]);
yeccpars2(560, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(561, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 563, [561 | __Ss], [__T | __Stack]);
yeccpars2(561, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(562, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(indAudrequestedEvent, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(563, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'IndAudEventsDescriptor'{requestID = __3, pkgdName = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(indAudeventsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(564, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [564 | __Ss], [__T | __Stack]);
yeccpars2(564, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(565, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 576, [565 | __Ss], [__T | __Stack]);
yeccpars2(565, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(566, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 567, [566 | __Ss], [__T | __Stack]);
yeccpars2(566, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(568, __Cat, [566 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(567, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 569, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [567 | __Ss], [__T | __Stack]);
yeccpars2(567, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(568, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_indAudEventBufferDescriptor(__1,__2),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(indAudeventSpec, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(569, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 574, [569 | __Ss], [__T | __Stack]);
yeccpars2(569, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(570, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventParameterName,__1},
 yeccpars2(yeccgoto(indAudeventSpecParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(571, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {streamID,__1},
 yeccpars2(yeccgoto(indAudeventSpecParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(572, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 573, [572 | __Ss], [__T | __Stack]);
yeccpars2(572, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(573, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(optIndAudeventSpecParameter, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(574, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [574 | __Ss], [__T | __Stack]);
yeccpars2(574, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(575, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(eventStream, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(576, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(indAudeventBufferDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(577, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 485, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 487, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 477, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 486, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 480, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 479, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 481, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 484, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 482, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 483, [577 | __Ss], [__T | __Stack]);
yeccpars2(577, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(578, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(auditDescriptorBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(579, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 577, [579 | __Ss], [__T | __Stack]);
yeccpars2(579, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(580, __Cat, [579 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(580, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(auditItemList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(581, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_auditDescriptor(__3),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(582, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 136, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 135, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 129, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 130, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'SubtractToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 137, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'ModifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 133, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'MoveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 134, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'AddToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 128, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 132, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, 'ContextAttrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 131, [582 | __Ss], [__T | __Stack]);
yeccpars2(582, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(583, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(actionRequestBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(584, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 582, [584 | __Ss], [__T | __Stack]);
yeccpars2(584, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(585, __Cat, [584 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(585, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(actionRequestItems, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(586, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_action_request(__3,__5),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(actionRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(587, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [587 | __Ss], [__T | __Stack]);
yeccpars2(587, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(588, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 589, [588 | __Ss], [__T | __Stack]);
yeccpars2(588, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(590, __Cat, [588 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(589, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 155, [589 | __Ss], [__T | __Stack]);
yeccpars2(589, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(590, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_commandRequest({subtractReq,__1},#'SubtractRequest'{terminationID = [__3], auditDescriptor = __4}),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(subtractRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(591, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 592, [591 | __Ss], [__T | __Stack]);
yeccpars2(591, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(592, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(optAuditDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(593, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [593 | __Ss], [__T | __Stack]);
yeccpars2(593, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(594, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 595, [594 | __Ss], [__T | __Stack]);
yeccpars2(594, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(595, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 596, [595 | __Ss], [__T | __Stack]);
yeccpars2(595, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(596, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 599, [596 | __Ss], [__T | __Stack]);
yeccpars2(596, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(597, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 598, [597 | __Ss], [__T | __Stack]);
yeccpars2(597, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(598, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_commandRequest({serviceChangeReq,__1},#'ServiceChangeRequest'{terminationID = [__3], serviceChangeParms = __5}),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(serviceChangeRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(599, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 607, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 605, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 604, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 603, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 602, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 601, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 600, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ServiceChangeIncompleteToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 606, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 485, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 487, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 477, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 486, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 480, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 479, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 481, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 484, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 482, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 483, [599 | __Ss], [__T | __Stack]);
yeccpars2(599, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(600, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 641, [600 | __Ss], [__T | __Stack]);
yeccpars2(600, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(601, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 639, [601 | __Ss], [__T | __Stack]);
yeccpars2(601, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(602, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 637, [602 | __Ss], [__T | __Stack]);
yeccpars2(602, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(603, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 635, [603 | __Ss], [__T | __Stack]);
yeccpars2(603, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(604, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 633, [604 | __Ss], [__T | __Stack]);
yeccpars2(604, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(605, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 629, [605 | __Ss], [__T | __Stack]);
yeccpars2(605, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(606, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  incomplete,
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(607, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 627, [607 | __Ss], [__T | __Stack]);
yeccpars2(607, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(608, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {audit_item,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(609, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {extension,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(610, 'GREATER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 220, [610 | __Ss], [__T | __Stack]);
yeccpars2(610, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 221, [610 | __Ss], [__T | __Stack]);
yeccpars2(610, 'NEQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 222, [610 | __Ss], [__T | __Stack]);
yeccpars2(610, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 219, [610 | __Ss], [__T | __Stack]);
yeccpars2(610, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(611, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_extensionParameter(__1),
 yeccpars2(yeccgoto(extensionParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(612, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {address,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(613, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {delay,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(614, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {method,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(615, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {mgc_id,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(616, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 621, [616 | __Ss], [__T | __Stack]);
yeccpars2(616, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(622, __Cat, [616 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(617, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {profile,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(618, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {reason,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(619, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {version,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(620, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {time_stamp,__1},
 yeccpars2(yeccgoto(serviceChangeParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(621, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 607, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 605, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 604, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 603, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 602, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 601, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 600, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ServiceChangeIncompleteToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 606, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 485, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 487, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 477, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 486, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 480, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 479, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 481, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 484, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 482, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 483, [621 | __Ss], [__T | __Stack]);
yeccpars2(621, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(622, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 623, [622 | __Ss], [__T | __Stack]);
yeccpars2(622, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(623, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_ServiceChangeParm([__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(serviceChangeDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(624, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 621, [624 | __Ss], [__T | __Stack]);
yeccpars2(624, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(625, __Cat, [624 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(625, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(626, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  setelement(#'PropertyParm'.name,__2,__1),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(extension, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(627, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [627 | __Ss], [__T | __Stack]);
yeccpars2(627, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(628, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_version(__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeVersion, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(629, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 89, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [629 | __Ss], [__T | __Stack]);
yeccpars2(629, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(93, __Cat, [629 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(630, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeAddress, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(631, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {portNumber,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeAddress, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(632, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint16(__1),
 yeccpars2(yeccgoto(portNumber, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(633, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 189, [633 | __Ss], [__T | __Stack]);
yeccpars2(633, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(634, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeReason, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(635, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [635 | __Ss], [__T | __Stack]);
yeccpars2(635, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(636, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_profile(__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeProfile, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(637, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 89, [637 | __Ss], [__T | __Stack]);
yeccpars2(637, 'LESSER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 88, [637 | __Ss], [__T | __Stack]);
yeccpars2(637, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [637 | __Ss], [__T | __Stack]);
yeccpars2(637, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(93, __Cat, [637 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(638, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __3,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeMgcId, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(639, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [639 | __Ss], [__T | __Stack]);
yeccpars2(639, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(640, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_serviceChangeMethod(__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeMethod, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(641, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [641 | __Ss], [__T | __Stack]);
yeccpars2(641, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(642, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint32(__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeDelay, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(643, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [643 | __Ss], [__T | __Stack]);
yeccpars2(643, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(644, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 645, [644 | __Ss], [__T | __Stack]);
yeccpars2(644, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(645, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 646, [645 | __Ss], [__T | __Stack]);
yeccpars2(645, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [645 | __Ss], [__T | __Stack]);
yeccpars2(645, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(646, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 651, [646 | __Ss], [__T | __Stack]);
yeccpars2(646, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(647, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'NotifyRequest'{errorDescriptor = __1},
 yeccpars2(yeccgoto(notifyRequestBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(648, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 650, [648 | __Ss], [__T | __Stack]);
yeccpars2(648, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(649, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'NotifyRequest'{observedEventsDescriptor = __1},
 yeccpars2(yeccgoto(notifyRequestBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(650, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_commandRequest({notifyReq,__1},setelement(#'NotifyRequest'.terminationID,__5,[__3])),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(notifyRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(651, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [651 | __Ss], [__T | __Stack]);
yeccpars2(651, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(652, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 653, [652 | __Ss], [__T | __Stack]);
yeccpars2(652, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(653, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [653 | __Ss], [__T | __Stack]);
yeccpars2(653, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [653 | __Ss], [__T | __Stack]);
yeccpars2(653, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(454, __Cat, [653 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(654, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 655, [654 | __Ss], [__T | __Stack]);
yeccpars2(654, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(656, __Cat, [654 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(655, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [655 | __Ss], [__T | __Stack]);
yeccpars2(655, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [655 | __Ss], [__T | __Stack]);
yeccpars2(655, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(454, __Cat, [655 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(656, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 657, [656 | __Ss], [__T | __Stack]);
yeccpars2(656, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(657, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'ObservedEventsDescriptor'{requestId = __3, observedEventLst = [__5|__6]},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(observedEventsDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(658, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 655, [658 | __Ss], [__T | __Stack]);
yeccpars2(658, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(659, __Cat, [658 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(659, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(observedEvents, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(660, 'ContextAttrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 661, [660 | __Ss], [__T | __Stack]);
yeccpars2(660, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(661, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 664, [661 | __Ss], [__T | __Stack]);
yeccpars2(661, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(662, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 663, [662 | __Ss], [__T | __Stack]);
yeccpars2(662, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(663, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_context_attr_audit_request(#'ContextAttrAuditRequest'{},__3),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(contextAudit, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(664, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'IEPSToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 666, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'PriorityToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 667, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'EmergencyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 665, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, 'TopologyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 668, [664 | __Ss], [__T | __Stack]);
yeccpars2(664, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(665, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  emergencyAudit,
 yeccpars2(yeccgoto(contextAuditProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(666, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  iepsCallind,
 yeccpars2(yeccgoto(contextAuditProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(667, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  priorityAudit,
 yeccpars2(yeccgoto(contextAuditProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(668, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  topologyAudit,
 yeccpars2(yeccgoto(contextAuditProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(669, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 671, [669 | __Ss], [__T | __Stack]);
yeccpars2(669, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(672, __Cat, [669 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(670, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {prop,__1},
 yeccpars2(yeccgoto(contextAuditProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(671, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'IEPSToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 666, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'PriorityToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 667, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'EmergencyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 665, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, 'TopologyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 668, [671 | __Ss], [__T | __Stack]);
yeccpars2(671, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(672, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 673, [672 | __Ss], [__T | __Stack]);
yeccpars2(672, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(673, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(indAudcontextAttrDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(674, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 671, [674 | __Ss], [__T | __Stack]);
yeccpars2(674, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(675, __Cat, [674 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(675, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(contextAuditProperties, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(676, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'PriorityToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 680, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'TopologyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 681, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'IEPSToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 679, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'EmergencyOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 677, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, 'EmergencyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 678, [676 | __Ss], [__T | __Stack]);
yeccpars2(676, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(677, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {emergency,false},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(678, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {emergency,true},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(679, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {iepsCallind,true},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(680, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 709, [680 | __Ss], [__T | __Stack]);
yeccpars2(680, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(681, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 692, [681 | __Ss], [__T | __Stack]);
yeccpars2(681, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(682, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 687, [682 | __Ss], [__T | __Stack]);
yeccpars2(682, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(688, __Cat, [682 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(683, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(contextAttrDescProp, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(684, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {priority,__1},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(685, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {prop,__1},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(686, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {topology,__1},
 yeccpars2(yeccgoto(contextProperty, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(687, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'PriorityToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 680, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'TopologyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 681, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'IEPSToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 679, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'EmergencyOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 677, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, 'EmergencyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 678, [687 | __Ss], [__T | __Stack]);
yeccpars2(687, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(688, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 689, [688 | __Ss], [__T | __Stack]);
yeccpars2(688, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(689, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(contextAttrDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(690, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 687, [690 | __Ss], [__T | __Stack]);
yeccpars2(690, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(691, __Cat, [690 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(691, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(contextAttrDescProps, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(692, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [692 | __Ss], [__T | __Stack]);
yeccpars2(692, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(693, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 701, [693 | __Ss], [__T | __Stack]);
yeccpars2(693, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(694, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(terminationA, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(695, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 696, [695 | __Ss], [__T | __Stack]);
yeccpars2(695, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(697, __Cat, [695 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(696, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [696 | __Ss], [__T | __Stack]);
yeccpars2(696, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(697, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 698, [697 | __Ss], [__T | __Stack]);
yeccpars2(697, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(698, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(topologyDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(699, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 696, [699 | __Ss], [__T | __Stack]);
yeccpars2(699, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(700, __Cat, [699 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(700, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(topologyTripleList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(701, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [701 | __Ss], [__T | __Stack]);
yeccpars2(701, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(702, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 704, [702 | __Ss], [__T | __Stack]);
yeccpars2(702, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(703, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __1,
 yeccpars2(yeccgoto(terminationB, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(704, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 707, [704 | __Ss], [__T | __Stack]);
yeccpars2(704, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 706, [704 | __Ss], [__T | __Stack]);
yeccpars2(704, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 705, [704 | __Ss], [__T | __Stack]);
yeccpars2(704, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(705, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  bothway,
 yeccpars2(yeccgoto(topologyDirection, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(706, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  isolate,
 yeccpars2(yeccgoto(topologyDirection, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(707, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  oneway,
 yeccpars2(yeccgoto(topologyDirection, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(708, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TopologyRequest'{terminationFrom = __1, terminationTo = __3, topologyDirection = __5},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(topologyTriple, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(709, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [709 | __Ss], [__T | __Stack]);
yeccpars2(709, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(710, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint16(__3),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(priority, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(711, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [711 | __Ss], [__T | __Stack]);
yeccpars2(711, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(712, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 589, [712 | __Ss], [__T | __Stack]);
yeccpars2(712, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(713, __Cat, [712 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(713, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_commandRequest({auditValueRequest,__1},#'AuditRequest'{terminationID = __3, auditDescriptor = __4}),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(714, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [714 | __Ss], [__T | __Stack]);
yeccpars2(714, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(715, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 589, [715 | __Ss], [__T | __Stack]);
yeccpars2(715, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(716, __Cat, [715 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(716, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_commandRequest({auditCapRequest,__1},#'AuditRequest'{terminationID = __3, auditDescriptor = __4}),
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(717, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 117, [717 | __Ss], [__T | __Stack]);
yeccpars2(717, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(718, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint32(__1),
 yeccpars2(yeccgoto(transactionID, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(719, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 720, [719 | __Ss], [__T | __Stack]);
yeccpars2(719, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(720, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 117, [720 | __Ss], [__T | __Stack]);
yeccpars2(720, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(721, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 119, [721 | __Ss], [__T | __Stack]);
yeccpars2(721, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(722, __Cat, [721 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(722, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 723, [722 | __Ss], [__T | __Stack]);
yeccpars2(722, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(723, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TransactionRequest'{transactionId = ensure_transactionID(__3), actions = [__5|__6]},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(transactionRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(724, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 119, [724 | __Ss], [__T | __Stack]);
yeccpars2(724, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(725, __Cat, [724 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(725, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 726, [725 | __Ss], [__T | __Stack]);
yeccpars2(725, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(726, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TransactionRequest'{transactionId = asn1_NOVALUE, actions = [__4|__5]},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(transactionRequest, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(727, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [727 | __Ss], [__T | __Stack]);
yeccpars2(727, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(728, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_transactionAck(__1),
 yeccpars2(yeccgoto(transactionAck, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(729, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 730, [729 | __Ss], [__T | __Stack]);
yeccpars2(729, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(731, __Cat, [729 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(730, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [730 | __Ss], [__T | __Stack]);
yeccpars2(730, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(731, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 732, [731 | __Ss], [__T | __Stack]);
yeccpars2(731, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(732, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(transactionResponseAck, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(733, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 730, [733 | __Ss], [__T | __Stack]);
yeccpars2(733, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(734, __Cat, [733 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(734, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(transactionAckList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(735, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [735 | __Ss], [__T | __Stack]);
yeccpars2(735, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(736, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 737, [736 | __Ss], [__T | __Stack]);
yeccpars2(736, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(737, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 738, [737 | __Ss], [__T | __Stack]);
yeccpars2(737, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(739, __Cat, [737 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(738, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 866, [738 | __Ss], [__T | __Stack]);
yeccpars2(738, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(739, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [739 | __Ss], [__T | __Stack]);
yeccpars2(739, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 740, [739 | __Ss], [__T | __Stack]);
yeccpars2(739, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(740, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 749, [740 | __Ss], [__T | __Stack]);
yeccpars2(740, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(741, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 745, [741 | __Ss], [__T | __Stack]);
yeccpars2(741, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(746, __Cat, [741 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(742, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {transactionError,__1},
 yeccpars2(yeccgoto(transactionReplyBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(743, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 744, [743 | __Ss], [__T | __Stack]);
yeccpars2(743, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(744, __Cat, __Ss,  [__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TransactionReply'{transactionId = __3, immAckRequired = __5, transactionResult = __6},
 __Nss = lists:nthtail(6, __Ss),
 yeccpars2(yeccgoto(transactionReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(745, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 740, [745 | __Ss], [__T | __Stack]);
yeccpars2(745, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(746, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {actionReplies,[__1|__2]},
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(transactionReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(747, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 745, [747 | __Ss], [__T | __Stack]);
yeccpars2(747, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(748, __Cat, [747 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(748, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(actionReplyList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(749, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [749 | __Ss], [__T | __Stack]);
yeccpars2(749, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(750, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 751, [750 | __Ss], [__T | __Stack]);
yeccpars2(750, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(751, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 758, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 757, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 753, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 754, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'SubtractToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 759, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'ModifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 755, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'MoveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 756, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'AddToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 752, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, 'ContextAttrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 131, [751 | __Ss], [__T | __Stack]);
yeccpars2(751, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(752, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  addReply,
 yeccpars2(yeccgoto(ammsToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(753, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 862, [753 | __Ss], [__T | __Stack]);
yeccpars2(753, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(754, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 842, [754 | __Ss], [__T | __Stack]);
yeccpars2(754, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(755, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  modReply,
 yeccpars2(yeccgoto(ammsToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(756, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  moveReply,
 yeccpars2(yeccgoto(ammsToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(757, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 836, [757 | __Ss], [__T | __Stack]);
yeccpars2(757, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(758, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 811, [758 | __Ss], [__T | __Stack]);
yeccpars2(758, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(759, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  subtractReply,
 yeccpars2(yeccgoto(ammsToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(760, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 810, [760 | __Ss], [__T | __Stack]);
yeccpars2(760, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(761, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {command,__1},
 yeccpars2(yeccgoto(commandReplys, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(762, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 774, [762 | __Ss], [__T | __Stack]);
yeccpars2(762, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(763, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {command,__1},
 yeccpars2(yeccgoto(commandReplys, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(764, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 769, [764 | __Ss], [__T | __Stack]);
yeccpars2(764, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(770, __Cat, [764 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(765, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {context,__1},
 yeccpars2(yeccgoto(commandReplys, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(766, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'ActionReply'{errorDescriptor = __1},
 yeccpars2(yeccgoto(actionReplyBody, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(767, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {command,__1},
 yeccpars2(yeccgoto(commandReplys, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(768, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {command,__1},
 yeccpars2(yeccgoto(commandReplys, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(769, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 758, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 757, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 753, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 754, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'SubtractToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 759, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'ModifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 755, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'MoveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 756, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'AddToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 752, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, 'ContextAttrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 131, [769 | __Ss], [__T | __Stack]);
yeccpars2(769, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(770, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_action_reply([__1|__2]),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(actionReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(771, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 769, [771 | __Ss], [__T | __Stack]);
yeccpars2(771, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(773, __Cat, [771 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(772, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [{error,__2}],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(commandReplyList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(773, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(commandReplyList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(774, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [774 | __Ss], [__T | __Stack]);
yeccpars2(774, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(775, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 776, [775 | __Ss], [__T | __Stack]);
yeccpars2(775, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(777, __Cat, [775 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(776, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 783, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 782, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 779, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 781, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 158, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 780, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 778, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [776 | __Ss], [__T | __Stack]);
yeccpars2(776, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(777, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {__1,#'AmmsReply'{terminationID = [__3], terminationAudit = __4}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(ammsReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(778, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 316, [778 | __Ss], [__T | __Stack]);
yeccpars2(778, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  mediaToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(779, 'LSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 296, [779 | __Ss], [__T | __Stack]);
yeccpars2(779, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 295, [779 | __Ss], [__T | __Stack]);
yeccpars2(779, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  modemToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(780, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 284, [780 | __Ss], [__T | __Stack]);
yeccpars2(780, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  muxToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(781, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 651, [781 | __Ss], [__T | __Stack]);
yeccpars2(781, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  observedEventsToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(782, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 803, [782 | __Ss], [__T | __Stack]);
yeccpars2(782, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  packagesToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(783, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 179, [783 | __Ss], [__T | __Stack]);
yeccpars2(783, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  statsToken,
 yeccpars2(yeccgoto(auditReturnItem, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(784, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditReturnItem,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(785, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 799, [785 | __Ss], [__T | __Stack]);
yeccpars2(785, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(800, __Cat, [785 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(786, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {digitMapDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(787, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {errorDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(788, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventBufferDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(789, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {eventsDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(790, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {mediaDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(791, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  '$undefined',
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(792, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {muxDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(793, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {observedEventsDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(794, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {packagesDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(795, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {signalsDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(796, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {statisticsDescriptor,__1},
 yeccpars2(yeccgoto(auditReturnParameter, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(797, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 798, [797 | __Ss], [__T | __Stack]);
yeccpars2(797, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(798, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(ammsReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(799, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 783, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 782, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 779, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 781, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 158, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 780, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 778, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [799 | __Ss], [__T | __Stack]);
yeccpars2(799, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(800, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_terminationAudit([__1|__2]),
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(terminationAudit, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(801, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 799, [801 | __Ss], [__T | __Stack]);
yeccpars2(801, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(802, __Cat, [801 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(802, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(auditReturnParameterList, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(803, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [803 | __Ss], [__T | __Stack]);
yeccpars2(803, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(804, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 805, [804 | __Ss], [__T | __Stack]);
yeccpars2(804, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(806, __Cat, [804 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(805, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [805 | __Ss], [__T | __Stack]);
yeccpars2(805, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(806, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 807, [806 | __Ss], [__T | __Stack]);
yeccpars2(806, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(807, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__3|__4],
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(packagesDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(808, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 805, [808 | __Ss], [__T | __Stack]);
yeccpars2(808, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(809, __Cat, [808 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(809, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(packagesItems, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(810, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  setelement(#'ActionReply'.contextId,__5,__3),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(actionReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(811, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [811 | __Ss], [__T | __Stack]);
yeccpars2(811, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(812, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 813, [812 | __Ss], [__T | __Stack]);
yeccpars2(812, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  {serviceChangeResParms,#'ServiceChangeResParm'{}},
 yeccpars2(814, __Cat, [812 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(813, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 815, [813 | __Ss], [__T | __Stack]);
yeccpars2(813, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [813 | __Ss], [__T | __Stack]);
yeccpars2(813, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(814, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {serviceChangeReply,#'ServiceChangeReply'{terminationID = [__3], serviceChangeResult = __4}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(serviceChangeReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(815, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 820, [815 | __Ss], [__T | __Stack]);
yeccpars2(815, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(816, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 819, [816 | __Ss], [__T | __Stack]);
yeccpars2(816, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(817, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 818, [817 | __Ss], [__T | __Stack]);
yeccpars2(817, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(818, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {serviceChangeResParms,__2},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(819, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {errorDescriptor,__2},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(serviceChangeReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(820, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [820 | __Ss], [__T | __Stack]);
yeccpars2(820, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 824, [820 | __Ss], [__T | __Stack]);
yeccpars2(820, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 822, [820 | __Ss], [__T | __Stack]);
yeccpars2(820, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 821, [820 | __Ss], [__T | __Stack]);
yeccpars2(820, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 823, [820 | __Ss], [__T | __Stack]);
yeccpars2(820, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(821, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 637, [821 | __Ss], [__T | __Stack]);
yeccpars2(821, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(822, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 635, [822 | __Ss], [__T | __Stack]);
yeccpars2(822, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(823, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 629, [823 | __Ss], [__T | __Stack]);
yeccpars2(823, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(824, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 627, [824 | __Ss], [__T | __Stack]);
yeccpars2(824, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(825, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 831, [825 | __Ss], [__T | __Stack]);
yeccpars2(825, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(832, __Cat, [825 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(826, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {address,__1},
 yeccpars2(yeccgoto(servChgReplyParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(827, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {mgc_id,__1},
 yeccpars2(yeccgoto(servChgReplyParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(828, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {profile,__1},
 yeccpars2(yeccgoto(servChgReplyParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(829, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {version,__1},
 yeccpars2(yeccgoto(servChgReplyParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(830, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {time_stamp,__1},
 yeccpars2(yeccgoto(servChgReplyParm, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(831, 'TimeStampToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 451, [831 | __Ss], [__T | __Stack]);
yeccpars2(831, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 824, [831 | __Ss], [__T | __Stack]);
yeccpars2(831, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 822, [831 | __Ss], [__T | __Stack]);
yeccpars2(831, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 821, [831 | __Ss], [__T | __Stack]);
yeccpars2(831, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 823, [831 | __Ss], [__T | __Stack]);
yeccpars2(831, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(832, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 833, [832 | __Ss], [__T | __Stack]);
yeccpars2(832, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(833, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  merge_ServiceChangeResParm([__3|__4]),
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(serviceChangeReplyDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(834, 'COMMA', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 831, [834 | __Ss], [__T | __Stack]);
yeccpars2(834, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(835, __Cat, [834 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(835, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__2|__3],
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(servChgReplyParms, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(836, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [836 | __Ss], [__T | __Stack]);
yeccpars2(836, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(837, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 838, [837 | __Ss], [__T | __Stack]);
yeccpars2(837, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(839, __Cat, [837 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(838, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [838 | __Ss], [__T | __Stack]);
yeccpars2(838, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(839, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {notifyReply,#'NotifyReply'{terminationID = [__3], errorDescriptor = __4}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(notifyReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(840, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 841, [840 | __Ss], [__T | __Stack]);
yeccpars2(840, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(841, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  __2,
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(notifyReplyBody, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(842, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 843, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [842 | __Ss], [__T | __Stack]);
yeccpars2(842, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(843, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 849, [843 | __Ss], [__T | __Stack]);
yeccpars2(843, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(844, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditValueReply,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(auditReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(845, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 846, [845 | __Ss], [__T | __Stack]);
yeccpars2(845, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditResult,#'AuditResult'{terminationID = __1, terminationAuditResult = []}},
 yeccpars2(yeccgoto(auditOther, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(846, 'StatsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 783, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'PackagesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 782, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'DigitMapDescriptorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 156, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'ModemToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 779, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'ObservedEventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 781, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'SignalsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 162, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'EventsToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 158, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'MuxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 780, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'EventBufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 157, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'MediaToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 778, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 101, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, 'DigitMapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 478, [846 | __Ss], [__T | __Stack]);
yeccpars2(846, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(847, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 848, [847 | __Ss], [__T | __Stack]);
yeccpars2(847, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(848, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditResult,#'AuditResult'{terminationID = __1, terminationAuditResult = __3}},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditOther, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(849, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 852, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [849 | __Ss], [__T | __Stack]);
yeccpars2(849, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(850, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditValueReply,__4},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(851, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {contextAuditResult,__1},
 yeccpars2(yeccgoto(contextTerminationAudit, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(852, 'EQUAL', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 855, [852 | __Ss], [__T | __Stack]);
yeccpars2(852, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(853, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 854, [853 | __Ss], [__T | __Stack]);
yeccpars2(853, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(854, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {contextAuditResult,__2},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(contextTerminationAudit, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(855, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [855 | __Ss], [__T | __Stack]);
yeccpars2(855, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(856, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 858, [856 | __Ss], [__T | __Stack]);
yeccpars2(856, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(857, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_uint(__1,0,999),
 yeccpars2(yeccgoto(errorCode, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(858, 'QuotedChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 859, [858 | __Ss], [__T | __Stack]);
yeccpars2(858, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  asn1_NOVALUE,
 yeccpars2(860, __Cat, [858 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(859, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  value_of(__1),
 yeccpars2(yeccgoto(errorText, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(860, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 861, [860 | __Ss], [__T | __Stack]);
yeccpars2(860, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(861, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'ErrorDescriptor'{errorCode = __3, errorText = __5},
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(errorDescriptor, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(862, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 863, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [862 | __Ss], [__T | __Stack]);
yeccpars2(862, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(863, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 849, [863 | __Ss], [__T | __Stack]);
yeccpars2(863, __Cat, __Ss,  [__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  make_safe_token(__1),
 yeccpars2(yeccgoto(safeToken, hd(__Ss)), __Cat, __Ss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(864, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditCapReply,__3},
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(auditReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(865, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  {auditCapReply,__4},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(auditReply, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(866, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  'NULL',
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(optImmAckRequired, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(867, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [867 | __Ss], [__T | __Stack]);
yeccpars2(867, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(868, 'LBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 869, [868 | __Ss], [__T | __Stack]);
yeccpars2(868, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(869, 'RBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 870, [869 | __Ss], [__T | __Stack]);
yeccpars2(869, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(870, __Cat, __Ss,  [__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'TransactionPending'{transactionId = ensure_transactionID(__3)},
 __Nss = lists:nthtail(4, __Ss),
 yeccpars2(yeccgoto(transactionPending, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(871, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 871, [871 | __Ss], [__T | __Stack]);
yeccpars2(871, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(879, __Cat, [871 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(872, 'RSBRKT', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 875, [872 | __Ss], [__T | __Stack]);
yeccpars2(872, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(873, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 871, [873 | __Ss], [__T | __Stack]);
yeccpars2(873, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  [],
 yeccpars2(874, __Cat, [873 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(874, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [__1|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(daddr, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(875, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 876, [875 | __Ss], [__T | __Stack]);
yeccpars2(875, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_domainAddress(__2,asn1_NOVALUE),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(domainAddress, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(876, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [876 | __Ss], [__T | __Stack]);
yeccpars2(876, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(877, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [877 | __Ss], [__T | __Stack]);
yeccpars2(877, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(878, __Cat, [877 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(878, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_domainAddress(__2,__5),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(domainAddress, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(879, __Cat, __Ss,  [__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  [colon|__2],
 __Nss = lists:nthtail(1, __Ss),
 yeccpars2(yeccgoto(daddr, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(880, 'GREATER', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 881, [880 | __Ss], [__T | __Stack]);
yeccpars2(880, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(881, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 882, [881 | __Ss], [__T | __Stack]);
yeccpars2(881, __Cat, __Ss,  [__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_domainName(__2,asn1_NOVALUE),
 __Nss = lists:nthtail(2, __Ss),
 yeccpars2(yeccgoto(domainName, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(882, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [882 | __Ss], [__T | __Stack]);
yeccpars2(882, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(883, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [883 | __Ss], [__T | __Stack]);
yeccpars2(883, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(884, __Cat, [883 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(884, __Cat, __Ss,  [__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_domainName(__2,__5),
 __Nss = lists:nthtail(5, __Ss),
 yeccpars2(yeccgoto(domainName, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(885, __Cat, __Ss,  [__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  #'MegacoMessage'{authHeader = __2, mess = __3},
 __Nss = lists:nthtail(3, __Ss),
 yeccpars2(yeccgoto(megacoMessage, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(886, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [886 | __Ss], [__T | __Stack]);
yeccpars2(886, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(887, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 888, [887 | __Ss], [__T | __Stack]);
yeccpars2(887, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(888, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [888 | __Ss], [__T | __Stack]);
yeccpars2(888, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(889, 'COLON', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 890, [889 | __Ss], [__T | __Stack]);
yeccpars2(889, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(890, 'VersionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 85, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V91Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 84, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V90Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 83, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V76Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 82, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V34Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 81, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V32bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 80, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V32Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 79, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V22bisToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 78, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V22Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 77, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'V18Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 76, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'TransToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 75, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'TimeOutToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 74, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'TestToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 73, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'TerminationStateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 72, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SynchISDNToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 71, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'StreamToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 70, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SignalTypeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 69, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SignalListToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 68, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ServiceChangeAddressToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 64, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ServiceChangeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 65, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ServiceStatesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 66, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ServicesToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 67, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SendrecvToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 63, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SendonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 62, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ReservedValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 58, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ReservedGroupToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 57, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'RestartToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 60, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ResponseAckToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 59, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'RequestIDToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 56, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ReplyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 55, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'RecvonlyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 54, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 53, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ProfileToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 52, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'PendingToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 51, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OtherReasonToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 49, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OutOfSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 50, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OnOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 46, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OnToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 47, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 45, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'OnewayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 48, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'Nx64Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 44, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'NotifyCompletionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 42, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'NotifyToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 43, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ModeToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 41, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'MgcIdToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 40, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'MethodToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 39, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'LockStepToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 37, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'LoopbackToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 38, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'LocalControlToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 36, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'KeepActiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 35, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'InSvcToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 30, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'IsolateToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 34, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'InterruptByNewSignalsDescrToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 33, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'InterruptByEventToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 32, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'InactiveToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 31, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ImmAckRequiredToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 29, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'HandOffToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 28, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'H226Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 27, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'H223Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 26, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'H221Token', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 25, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'GracefulToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 24, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ForcedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 23, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'FailoverToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 22, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ErrorToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 21, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'EmbedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 20, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'DurationToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 19, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'DelayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 15, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'DisconnectedToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 18, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'DiscardToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 17, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'DirectionToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 16, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'ContextAuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 13, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'CtxToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 14, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'BufferToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 12, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'BriefToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 11, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'BothwayToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 10, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'AuthToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 9, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'AuditValueToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 8, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'AuditCapToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 6, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'AuditToken', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 7, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, 'SafeChars', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 61, [890 | __Ss], [__T | __Stack]);
yeccpars2(890, _, _, _, __T, _, _) ->
 yeccerror(__T);
yeccpars2(891, 'SEP', __Ss, __Stack, __T, __Ts, __Tzr) ->
 yeccpars1(__Ts, __Tzr, 1, [891 | __Ss], [__T | __Stack]);
yeccpars2(891, __Cat, __Ss,  __Stack, __T, __Ts, __Tzr) ->
 __Val =  no_sep,
 yeccpars2(892, __Cat, [891 | __Ss], [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(892, __Cat, __Ss,  [__8,__7,__6,__5,__4,__3,__2,__1|__Stack], __T, __Ts, __Tzr) ->
 __Val =  ensure_auth_header(__3,__5,__7),
 __Nss = lists:nthtail(7, __Ss),
 yeccpars2(yeccgoto(authenticationHeader, hd(__Nss)), __Cat, __Nss, [__Val | __Stack], __T, __Ts, __Tzr);
yeccpars2(__Other, _, _, _, _, _, _) ->
 exit({parser, __Other, missing_state_in_action_table}).

yeccgoto(actionReply, 739) ->
 741;
yeccgoto(actionReply, 745) ->
 747;
yeccgoto(actionReplyBody, 751) ->
 760;
yeccgoto(actionReplyList, 741) ->
 746;
yeccgoto(actionReplyList, 747) ->
 748;
yeccgoto(actionRequest, 116) ->
 118;
yeccgoto(actionRequest, 119) ->
 122;
yeccgoto(actionRequest, 717) ->
 724;
yeccgoto(actionRequest, 720) ->
 721;
yeccgoto(actionRequestBody, 127) ->
 138;
yeccgoto(actionRequestItem, 127) ->
 139;
yeccgoto(actionRequestItem, 582) ->
 584;
yeccgoto(actionRequestItems, 139) ->
 583;
yeccgoto(actionRequestItems, 584) ->
 585;
yeccgoto(actionRequestList, 118) ->
 120;
yeccgoto(actionRequestList, 122) ->
 123;
yeccgoto(actionRequestList, 721) ->
 722;
yeccgoto(actionRequestList, 724) ->
 725;
yeccgoto(alternativeValue, 219) ->
 229;
yeccgoto(ammParameter, 153) ->
 164;
yeccgoto(ammParameter, 174) ->
 177;
yeccgoto(ammParameters, 164) ->
 175;
yeccgoto(ammParameters, 177) ->
 178;
yeccgoto(ammRequest, 127) ->
 140;
yeccgoto(ammRequest, 582) ->
 140;
yeccgoto(ammRequestBody, 152) ->
 154;
yeccgoto(ammToken, 127) ->
 141;
yeccgoto(ammToken, 582) ->
 141;
yeccgoto(ammsReply, 751) ->
 761;
yeccgoto(ammsReply, 769) ->
 761;
yeccgoto(ammsReplyBody, 775) ->
 777;
yeccgoto(ammsToken, 751) ->
 762;
yeccgoto(ammsToken, 769) ->
 762;
yeccgoto(auditDescriptor, 153) ->
 165;
yeccgoto(auditDescriptor, 174) ->
 165;
yeccgoto(auditDescriptor, 589) ->
 591;
yeccgoto(auditDescriptorBody, 476) ->
 488;
yeccgoto(auditItem, 476) ->
 489;
yeccgoto(auditItem, 577) ->
 579;
yeccgoto(auditItem, 599) ->
 608;
yeccgoto(auditItem, 621) ->
 608;
yeccgoto(auditItemList, 489) ->
 578;
yeccgoto(auditItemList, 579) ->
 580;
yeccgoto(auditOther, 842) ->
 844;
yeccgoto(auditOther, 862) ->
 864;
yeccgoto(auditReply, 751) ->
 763;
yeccgoto(auditReply, 769) ->
 763;
yeccgoto(auditRequest, 127) ->
 142;
yeccgoto(auditRequest, 582) ->
 142;
yeccgoto(auditReturnItem, 476) ->
 490;
yeccgoto(auditReturnItem, 577) ->
 490;
yeccgoto(auditReturnItem, 599) ->
 490;
yeccgoto(auditReturnItem, 621) ->
 490;
yeccgoto(auditReturnItem, 776) ->
 784;
yeccgoto(auditReturnItem, 799) ->
 784;
yeccgoto(auditReturnItem, 846) ->
 784;
yeccgoto(auditReturnParameter, 776) ->
 785;
yeccgoto(auditReturnParameter, 799) ->
 801;
yeccgoto(auditReturnParameter, 846) ->
 785;
yeccgoto(auditReturnParameterList, 785) ->
 800;
yeccgoto(auditReturnParameterList, 801) ->
 802;
yeccgoto(authenticationHeader, 3) ->
 5;
yeccgoto(commandReplyList, 764) ->
 770;
yeccgoto(commandReplyList, 771) ->
 773;
yeccgoto(commandReplys, 751) ->
 764;
yeccgoto(commandReplys, 769) ->
 771;
yeccgoto(commandRequest, 127) ->
 143;
yeccgoto(commandRequest, 582) ->
 143;
yeccgoto(contextAttrDescProp, 676) ->
 682;
yeccgoto(contextAttrDescProp, 687) ->
 690;
yeccgoto(contextAttrDescProps, 682) ->
 688;
yeccgoto(contextAttrDescProps, 690) ->
 691;
yeccgoto(contextAttrDescriptor, 127) ->
 144;
yeccgoto(contextAttrDescriptor, 582) ->
 144;
yeccgoto(contextAttrDescriptor, 751) ->
 144;
yeccgoto(contextAttrDescriptor, 769) ->
 144;
yeccgoto(contextAudit, 127) ->
 145;
yeccgoto(contextAudit, 582) ->
 145;
yeccgoto(contextAuditProperties, 669) ->
 672;
yeccgoto(contextAuditProperties, 674) ->
 675;
yeccgoto(contextAuditProperty, 664) ->
 669;
yeccgoto(contextAuditProperty, 671) ->
 674;
yeccgoto(contextID, 124) ->
 125;
yeccgoto(contextID, 749) ->
 750;
yeccgoto(contextProperties, 127) ->
 146;
yeccgoto(contextProperties, 582) ->
 146;
yeccgoto(contextProperties, 751) ->
 765;
yeccgoto(contextProperties, 769) ->
 765;
yeccgoto(contextProperty, 676) ->
 683;
yeccgoto(contextProperty, 687) ->
 683;
yeccgoto(contextTerminationAudit, 843) ->
 850;
yeccgoto(contextTerminationAudit, 863) ->
 865;
yeccgoto(daddr, 89) ->
 872;
yeccgoto(daddr, 871) ->
 879;
yeccgoto(daddr, 873) ->
 874;
yeccgoto(deviceName, 93) ->
 95;
yeccgoto(digitMapDescriptor, 153) ->
 166;
yeccgoto(digitMapDescriptor, 174) ->
 166;
yeccgoto(digitMapDescriptor, 776) ->
 786;
yeccgoto(digitMapDescriptor, 799) ->
 786;
yeccgoto(digitMapDescriptor, 846) ->
 786;
yeccgoto(direction, 268) ->
 272;
yeccgoto(domainAddress, 87) ->
 90;
yeccgoto(domainAddress, 629) ->
 90;
yeccgoto(domainAddress, 637) ->
 90;
yeccgoto(domainName, 87) ->
 91;
yeccgoto(domainName, 629) ->
 91;
yeccgoto(domainName, 637) ->
 91;
yeccgoto(embedFirst, 415) ->
 417;
yeccgoto(embedFirst, 419) ->
 421;
yeccgoto(embedNoSig, 397) ->
 402;
yeccgoto(embedNoSig, 410) ->
 402;
yeccgoto(embedSig, 434) ->
 438;
yeccgoto(embedSig, 442) ->
 438;
yeccgoto(embedWithSig, 397) ->
 403;
yeccgoto(embedWithSig, 410) ->
 403;
yeccgoto(errorCode, 855) ->
 856;
yeccgoto(errorDescriptor, 92) ->
 106;
yeccgoto(errorDescriptor, 645) ->
 647;
yeccgoto(errorDescriptor, 739) ->
 742;
yeccgoto(errorDescriptor, 751) ->
 766;
yeccgoto(errorDescriptor, 769) ->
 772;
yeccgoto(errorDescriptor, 776) ->
 787;
yeccgoto(errorDescriptor, 799) ->
 787;
yeccgoto(errorDescriptor, 813) ->
 816;
yeccgoto(errorDescriptor, 838) ->
 840;
yeccgoto(errorDescriptor, 846) ->
 787;
yeccgoto(errorDescriptor, 849) ->
 853;
yeccgoto(errorText, 858) ->
 860;
yeccgoto(eventBufferControl, 333) ->
 336;
yeccgoto(eventBufferControl, 340) ->
 336;
yeccgoto(eventBufferControlState, 350) ->
 353;
yeccgoto(eventBufferDescriptor, 153) ->
 167;
yeccgoto(eventBufferDescriptor, 174) ->
 167;
yeccgoto(eventBufferDescriptor, 776) ->
 788;
yeccgoto(eventBufferDescriptor, 799) ->
 788;
yeccgoto(eventBufferDescriptor, 846) ->
 788;
yeccgoto(eventDM, 397) ->
 404;
yeccgoto(eventDM, 410) ->
 404;
yeccgoto(eventDM, 434) ->
 439;
yeccgoto(eventDM, 442) ->
 439;
yeccgoto(eventParameter, 397) ->
 405;
yeccgoto(eventParameter, 410) ->
 413;
yeccgoto(eventParameterName, 397) ->
 406;
yeccgoto(eventParameterName, 410) ->
 406;
yeccgoto(eventParameterName, 434) ->
 406;
yeccgoto(eventParameterName, 442) ->
 406;
yeccgoto(eventParameterName, 460) ->
 406;
yeccgoto(eventParameterName, 464) ->
 406;
yeccgoto(eventParameterName, 567) ->
 570;
yeccgoto(eventParameters, 405) ->
 411;
yeccgoto(eventParameters, 413) ->
 414;
yeccgoto(eventSpec, 450) ->
 452;
yeccgoto(eventSpec, 471) ->
 474;
yeccgoto(eventSpecList, 452) ->
 472;
yeccgoto(eventSpecList, 474) ->
 475;
yeccgoto(eventStream, 567) ->
 571;
yeccgoto(eventStreamOrOther, 397) ->
 407;
yeccgoto(eventStreamOrOther, 410) ->
 407;
yeccgoto(eventStreamOrOther, 434) ->
 440;
yeccgoto(eventStreamOrOther, 442) ->
 440;
yeccgoto(eventStreamOrOther, 460) ->
 462;
yeccgoto(eventStreamOrOther, 464) ->
 462;
yeccgoto(eventsDescriptor, 153) ->
 168;
yeccgoto(eventsDescriptor, 174) ->
 168;
yeccgoto(eventsDescriptor, 776) ->
 789;
yeccgoto(eventsDescriptor, 799) ->
 789;
yeccgoto(eventsDescriptor, 846) ->
 789;
yeccgoto(extension, 599) ->
 609;
yeccgoto(extension, 621) ->
 609;
yeccgoto(extensionParameter, 599) ->
 610;
yeccgoto(extensionParameter, 621) ->
 610;
yeccgoto(indAudauditReturnParameter, 476) ->
 491;
yeccgoto(indAudauditReturnParameter, 500) ->
 508;
yeccgoto(indAudauditReturnParameter, 577) ->
 491;
yeccgoto(indAudauditReturnParameter, 599) ->
 491;
yeccgoto(indAudauditReturnParameter, 621) ->
 491;
yeccgoto(indAudcontextAttrDescriptor, 660) ->
 662;
yeccgoto(indAuddigitMapDescriptor, 476) ->
 492;
yeccgoto(indAuddigitMapDescriptor, 500) ->
 492;
yeccgoto(indAuddigitMapDescriptor, 577) ->
 492;
yeccgoto(indAuddigitMapDescriptor, 599) ->
 492;
yeccgoto(indAuddigitMapDescriptor, 621) ->
 492;
yeccgoto(indAudeventBufferDescriptor, 476) ->
 493;
yeccgoto(indAudeventBufferDescriptor, 500) ->
 493;
yeccgoto(indAudeventBufferDescriptor, 577) ->
 493;
yeccgoto(indAudeventBufferDescriptor, 599) ->
 493;
yeccgoto(indAudeventBufferDescriptor, 621) ->
 493;
yeccgoto(indAudeventSpec, 564) ->
 565;
yeccgoto(indAudeventSpecParameter, 567) ->
 572;
yeccgoto(indAudeventsDescriptor, 476) ->
 494;
yeccgoto(indAudeventsDescriptor, 500) ->
 494;
yeccgoto(indAudeventsDescriptor, 577) ->
 494;
yeccgoto(indAudeventsDescriptor, 599) ->
 494;
yeccgoto(indAudeventsDescriptor, 621) ->
 494;
yeccgoto(indAudlocalControlDescriptor, 530) ->
 534;
yeccgoto(indAudlocalControlDescriptor, 547) ->
 534;
yeccgoto(indAudlocalParm, 550) ->
 551;
yeccgoto(indAudlocalParm, 553) ->
 556;
yeccgoto(indAudlocalParmList, 551) ->
 554;
yeccgoto(indAudlocalParmList, 556) ->
 557;
yeccgoto(indAudmediaDescriptor, 476) ->
 495;
yeccgoto(indAudmediaDescriptor, 500) ->
 495;
yeccgoto(indAudmediaDescriptor, 577) ->
 495;
yeccgoto(indAudmediaDescriptor, 599) ->
 495;
yeccgoto(indAudmediaDescriptor, 621) ->
 495;
yeccgoto(indAudmediaParm, 530) ->
 535;
yeccgoto(indAudpackagesDescriptor, 476) ->
 496;
yeccgoto(indAudpackagesDescriptor, 500) ->
 496;
yeccgoto(indAudpackagesDescriptor, 577) ->
 496;
yeccgoto(indAudpackagesDescriptor, 599) ->
 496;
yeccgoto(indAudpackagesDescriptor, 621) ->
 496;
yeccgoto(indAudrequestedEvent, 560) ->
 561;
yeccgoto(indAudsignalList, 513) ->
 517;
yeccgoto(indAudsignalParm, 513) ->
 518;
yeccgoto(indAudsignalsDescriptor, 476) ->
 497;
yeccgoto(indAudsignalsDescriptor, 500) ->
 497;
yeccgoto(indAudsignalsDescriptor, 577) ->
 497;
yeccgoto(indAudsignalsDescriptor, 599) ->
 497;
yeccgoto(indAudsignalsDescriptor, 621) ->
 497;
yeccgoto(indAudstatisticsDescriptor, 476) ->
 498;
yeccgoto(indAudstatisticsDescriptor, 500) ->
 498;
yeccgoto(indAudstatisticsDescriptor, 530) ->
 536;
yeccgoto(indAudstatisticsDescriptor, 547) ->
 536;
yeccgoto(indAudstatisticsDescriptor, 577) ->
 498;
yeccgoto(indAudstatisticsDescriptor, 599) ->
 498;
yeccgoto(indAudstatisticsDescriptor, 621) ->
 498;
yeccgoto(indAudstreamDescriptor, 530) ->
 537;
yeccgoto(indAudstreamParm, 530) ->
 538;
yeccgoto(indAudstreamParm, 547) ->
 548;
yeccgoto(indAudterminationAudit, 476) ->
 499;
yeccgoto(indAudterminationAudit, 577) ->
 499;
yeccgoto(indAudterminationAudit, 599) ->
 499;
yeccgoto(indAudterminationAudit, 621) ->
 499;
yeccgoto(indAudterminationAuditList, 491) ->
 501;
yeccgoto(indAudterminationAuditList, 508) ->
 509;
yeccgoto(indAudterminationStateDescriptor, 530) ->
 539;
yeccgoto(indAudterminationStateParm, 541) ->
 542;
yeccgoto(localControlDescriptor, 316) ->
 322;
yeccgoto(localControlDescriptor, 328) ->
 322;
yeccgoto(localControlDescriptor, 356) ->
 322;
yeccgoto(localControlDescriptor, 358) ->
 322;
yeccgoto(localParm, 363) ->
 367;
yeccgoto(localParm, 369) ->
 372;
yeccgoto(localParmList, 367) ->
 370;
yeccgoto(localParmList, 372) ->
 373;
yeccgoto(mId, 87) ->
 92;
yeccgoto(mId, 629) ->
 630;
yeccgoto(mId, 637) ->
 638;
yeccgoto(mediaDescriptor, 153) ->
 169;
yeccgoto(mediaDescriptor, 174) ->
 169;
yeccgoto(mediaDescriptor, 776) ->
 790;
yeccgoto(mediaDescriptor, 799) ->
 790;
yeccgoto(mediaDescriptor, 846) ->
 790;
yeccgoto(mediaParm, 316) ->
 323;
yeccgoto(mediaParm, 328) ->
 331;
yeccgoto(mediaParmList, 323) ->
 329;
yeccgoto(mediaParmList, 331) ->
 332;
yeccgoto(megacoMessage, 0) ->
 2;
yeccgoto(message, 5) ->
 86;
yeccgoto(messageBody, 92) ->
 107;
yeccgoto(modemDescriptor, 153) ->
 170;
yeccgoto(modemDescriptor, 174) ->
 170;
yeccgoto(modemDescriptor, 776) ->
 791;
yeccgoto(modemDescriptor, 799) ->
 791;
yeccgoto(modemDescriptor, 846) ->
 791;
yeccgoto(modemType, 295) ->
 314;
yeccgoto(modemType, 296) ->
 297;
yeccgoto(modemType, 299) ->
 312;
yeccgoto(modemTypeList, 297) ->
 300;
yeccgoto(modemTypeList, 312) ->
 313;
yeccgoto(mtpAddress, 93) ->
 96;
yeccgoto(muxDescriptor, 153) ->
 171;
yeccgoto(muxDescriptor, 174) ->
 171;
yeccgoto(muxDescriptor, 776) ->
 792;
yeccgoto(muxDescriptor, 799) ->
 792;
yeccgoto(muxDescriptor, 846) ->
 792;
yeccgoto(muxType, 284) ->
 285;
yeccgoto(notificationReason, 255) ->
 260;
yeccgoto(notificationReason, 261) ->
 264;
yeccgoto(notificationReasons, 260) ->
 262;
yeccgoto(notificationReasons, 264) ->
 265;
yeccgoto(notifyReply, 751) ->
 767;
yeccgoto(notifyReply, 769) ->
 767;
yeccgoto(notifyReplyBody, 837) ->
 839;
yeccgoto(notifyRequest, 127) ->
 147;
yeccgoto(notifyRequest, 582) ->
 147;
yeccgoto(notifyRequestBody, 645) ->
 648;
yeccgoto(observedEvent, 450) ->
 453;
yeccgoto(observedEvent, 471) ->
 453;
yeccgoto(observedEvent, 653) ->
 654;
yeccgoto(observedEvent, 655) ->
 658;
yeccgoto(observedEventBody, 459) ->
 461;
yeccgoto(observedEventBody, 469) ->
 470;
yeccgoto(observedEventParameter, 460) ->
 463;
yeccgoto(observedEventParameter, 464) ->
 467;
yeccgoto(observedEventParameters, 463) ->
 465;
yeccgoto(observedEventParameters, 467) ->
 468;
yeccgoto(observedEvents, 654) ->
 656;
yeccgoto(observedEvents, 658) ->
 659;
yeccgoto(observedEventsDescriptor, 645) ->
 649;
yeccgoto(observedEventsDescriptor, 776) ->
 793;
yeccgoto(observedEventsDescriptor, 799) ->
 793;
yeccgoto(observedEventsDescriptor, 846) ->
 793;
yeccgoto(onOrOff, 374) ->
 377;
yeccgoto(onOrOff, 378) ->
 379;
yeccgoto(optAuditDescriptor, 588) ->
 590;
yeccgoto(optAuditDescriptor, 712) ->
 713;
yeccgoto(optAuditDescriptor, 715) ->
 716;
yeccgoto(optImmAckRequired, 737) ->
 739;
yeccgoto(optIndAudeventSpecParameter, 566) ->
 568;
yeccgoto(optIndAudsignalParm, 486) ->
 514;
yeccgoto(optIndAudsignalParm, 506) ->
 514;
yeccgoto(optPropertyParms, 301) ->
 303;
yeccgoto(optPropertyParms, 314) ->
 315;
yeccgoto(optSep, 0) ->
 3;
yeccgoto(optSep, 87) ->
 93;
yeccgoto(optSep, 95) ->
 100;
yeccgoto(optSep, 96) ->
 99;
yeccgoto(optSep, 450) ->
 454;
yeccgoto(optSep, 455) ->
 456;
yeccgoto(optSep, 457) ->
 458;
yeccgoto(optSep, 471) ->
 454;
yeccgoto(optSep, 629) ->
 93;
yeccgoto(optSep, 637) ->
 93;
yeccgoto(optSep, 653) ->
 454;
yeccgoto(optSep, 655) ->
 454;
yeccgoto(optSep, 877) ->
 878;
yeccgoto(optSep, 883) ->
 884;
yeccgoto(optSep, 891) ->
 892;
yeccgoto(packagesDescriptor, 776) ->
 794;
yeccgoto(packagesDescriptor, 799) ->
 794;
yeccgoto(packagesDescriptor, 846) ->
 794;
yeccgoto(packagesItem, 526) ->
 527;
yeccgoto(packagesItem, 803) ->
 804;
yeccgoto(packagesItem, 805) ->
 808;
yeccgoto(packagesItems, 804) ->
 806;
yeccgoto(packagesItems, 808) ->
 809;
yeccgoto(parmValue, 212) ->
 223;
yeccgoto(parmValue, 304) ->
 311;
yeccgoto(parmValue, 406) ->
 409;
yeccgoto(parmValue, 610) ->
 626;
yeccgoto(pathName, 93) ->
 97;
yeccgoto(pkgdName, 179) ->
 180;
yeccgoto(pkgdName, 183) ->
 180;
yeccgoto(pkgdName, 192) ->
 194;
yeccgoto(pkgdName, 199) ->
 194;
yeccgoto(pkgdName, 276) ->
 194;
yeccgoto(pkgdName, 279) ->
 194;
yeccgoto(pkgdName, 302) ->
 304;
yeccgoto(pkgdName, 306) ->
 304;
yeccgoto(pkgdName, 333) ->
 304;
yeccgoto(pkgdName, 340) ->
 304;
yeccgoto(pkgdName, 363) ->
 304;
yeccgoto(pkgdName, 369) ->
 304;
yeccgoto(pkgdName, 389) ->
 390;
yeccgoto(pkgdName, 392) ->
 390;
yeccgoto(pkgdName, 426) ->
 427;
yeccgoto(pkgdName, 429) ->
 427;
yeccgoto(pkgdName, 454) ->
 469;
yeccgoto(pkgdName, 458) ->
 459;
yeccgoto(pkgdName, 510) ->
 511;
yeccgoto(pkgdName, 513) ->
 194;
yeccgoto(pkgdName, 523) ->
 194;
yeccgoto(pkgdName, 560) ->
 562;
yeccgoto(pkgdName, 564) ->
 566;
yeccgoto(pkgdName, 664) ->
 670;
yeccgoto(pkgdName, 671) ->
 670;
yeccgoto(pkgdName, 676) ->
 304;
yeccgoto(pkgdName, 687) ->
 304;
yeccgoto(portNumber, 629) ->
 631;
yeccgoto(portNumber, 876) ->
 877;
yeccgoto(portNumber, 882) ->
 883;
yeccgoto(priority, 676) ->
 684;
yeccgoto(priority, 687) ->
 684;
yeccgoto(propertyParm, 302) ->
 305;
yeccgoto(propertyParm, 306) ->
 309;
yeccgoto(propertyParm, 333) ->
 337;
yeccgoto(propertyParm, 340) ->
 337;
yeccgoto(propertyParm, 363) ->
 368;
yeccgoto(propertyParm, 369) ->
 368;
yeccgoto(propertyParm, 676) ->
 685;
yeccgoto(propertyParm, 687) ->
 685;
yeccgoto(propertyParms, 305) ->
 307;
yeccgoto(propertyParms, 309) ->
 310;
yeccgoto(requestID, 251) ->
 252;
yeccgoto(requestID, 387) ->
 388;
yeccgoto(requestID, 424) ->
 425;
yeccgoto(requestID, 558) ->
 559;
yeccgoto(requestID, 651) ->
 652;
yeccgoto(requestedEvent, 389) ->
 391;
yeccgoto(requestedEvent, 392) ->
 395;
yeccgoto(requestedEventBody, 390) ->
 398;
yeccgoto(requestedEvents, 391) ->
 393;
yeccgoto(requestedEvents, 395) ->
 396;
yeccgoto(safeToken, 5) ->
 87;
yeccgoto(safeToken, 88) ->
 880;
yeccgoto(safeToken, 89) ->
 873;
yeccgoto(safeToken, 93) ->
 98;
yeccgoto(safeToken, 115) ->
 718;
yeccgoto(safeToken, 124) ->
 126;
yeccgoto(safeToken, 150) ->
 151;
yeccgoto(safeToken, 179) ->
 181;
yeccgoto(safeToken, 183) ->
 181;
yeccgoto(safeToken, 188) ->
 190;
yeccgoto(safeToken, 192) ->
 181;
yeccgoto(safeToken, 199) ->
 181;
yeccgoto(safeToken, 204) ->
 212;
yeccgoto(safeToken, 214) ->
 212;
yeccgoto(safeToken, 219) ->
 190;
yeccgoto(safeToken, 220) ->
 190;
yeccgoto(safeToken, 221) ->
 190;
yeccgoto(safeToken, 222) ->
 190;
yeccgoto(safeToken, 227) ->
 190;
yeccgoto(safeToken, 228) ->
 190;
yeccgoto(safeToken, 232) ->
 190;
yeccgoto(safeToken, 233) ->
 190;
yeccgoto(safeToken, 243) ->
 244;
yeccgoto(safeToken, 251) ->
 253;
yeccgoto(safeToken, 266) ->
 267;
yeccgoto(safeToken, 273) ->
 274;
yeccgoto(safeToken, 276) ->
 181;
yeccgoto(safeToken, 279) ->
 181;
yeccgoto(safeToken, 284) ->
 286;
yeccgoto(safeToken, 287) ->
 151;
yeccgoto(safeToken, 290) ->
 151;
yeccgoto(safeToken, 295) ->
 298;
yeccgoto(safeToken, 296) ->
 298;
yeccgoto(safeToken, 299) ->
 298;
yeccgoto(safeToken, 302) ->
 181;
yeccgoto(safeToken, 306) ->
 181;
yeccgoto(safeToken, 333) ->
 181;
yeccgoto(safeToken, 340) ->
 181;
yeccgoto(safeToken, 354) ->
 244;
yeccgoto(safeToken, 363) ->
 181;
yeccgoto(safeToken, 369) ->
 181;
yeccgoto(safeToken, 387) ->
 253;
yeccgoto(safeToken, 389) ->
 181;
yeccgoto(safeToken, 392) ->
 181;
yeccgoto(safeToken, 397) ->
 408;
yeccgoto(safeToken, 410) ->
 408;
yeccgoto(safeToken, 424) ->
 253;
yeccgoto(safeToken, 426) ->
 181;
yeccgoto(safeToken, 429) ->
 181;
yeccgoto(safeToken, 434) ->
 408;
yeccgoto(safeToken, 442) ->
 408;
yeccgoto(safeToken, 454) ->
 181;
yeccgoto(safeToken, 458) ->
 181;
yeccgoto(safeToken, 460) ->
 408;
yeccgoto(safeToken, 464) ->
 408;
yeccgoto(safeToken, 510) ->
 181;
yeccgoto(safeToken, 513) ->
 181;
yeccgoto(safeToken, 521) ->
 274;
yeccgoto(safeToken, 523) ->
 181;
yeccgoto(safeToken, 526) ->
 528;
yeccgoto(safeToken, 541) ->
 543;
yeccgoto(safeToken, 545) ->
 244;
yeccgoto(safeToken, 550) ->
 552;
yeccgoto(safeToken, 553) ->
 552;
yeccgoto(safeToken, 558) ->
 253;
yeccgoto(safeToken, 560) ->
 181;
yeccgoto(safeToken, 564) ->
 181;
yeccgoto(safeToken, 567) ->
 408;
yeccgoto(safeToken, 574) ->
 244;
yeccgoto(safeToken, 587) ->
 151;
yeccgoto(safeToken, 593) ->
 151;
yeccgoto(safeToken, 599) ->
 611;
yeccgoto(safeToken, 621) ->
 611;
yeccgoto(safeToken, 627) ->
 628;
yeccgoto(safeToken, 629) ->
 632;
yeccgoto(safeToken, 633) ->
 190;
yeccgoto(safeToken, 635) ->
 636;
yeccgoto(safeToken, 639) ->
 640;
yeccgoto(safeToken, 641) ->
 642;
yeccgoto(safeToken, 643) ->
 151;
yeccgoto(safeToken, 651) ->
 253;
yeccgoto(safeToken, 664) ->
 181;
yeccgoto(safeToken, 671) ->
 181;
yeccgoto(safeToken, 676) ->
 181;
yeccgoto(safeToken, 687) ->
 181;
yeccgoto(safeToken, 692) ->
 151;
yeccgoto(safeToken, 696) ->
 151;
yeccgoto(safeToken, 701) ->
 151;
yeccgoto(safeToken, 709) ->
 710;
yeccgoto(safeToken, 711) ->
 151;
yeccgoto(safeToken, 714) ->
 151;
yeccgoto(safeToken, 727) ->
 728;
yeccgoto(safeToken, 730) ->
 728;
yeccgoto(safeToken, 735) ->
 718;
yeccgoto(safeToken, 749) ->
 126;
yeccgoto(safeToken, 774) ->
 151;
yeccgoto(safeToken, 803) ->
 528;
yeccgoto(safeToken, 805) ->
 528;
yeccgoto(safeToken, 811) ->
 151;
yeccgoto(safeToken, 836) ->
 151;
yeccgoto(safeToken, 842) ->
 151;
yeccgoto(safeToken, 849) ->
 151;
yeccgoto(safeToken, 855) ->
 857;
yeccgoto(safeToken, 862) ->
 151;
yeccgoto(safeToken, 867) ->
 718;
yeccgoto(safeToken, 871) ->
 873;
yeccgoto(safeToken, 873) ->
 873;
yeccgoto(safeToken, 876) ->
 632;
yeccgoto(safeToken, 882) ->
 632;
yeccgoto(safeToken, 886) ->
 887;
yeccgoto(safeToken, 888) ->
 889;
yeccgoto(safeToken, 890) ->
 891;
yeccgoto(secondEventParameter, 434) ->
 441;
yeccgoto(secondEventParameter, 442) ->
 445;
yeccgoto(secondEventParameters, 441) ->
 443;
yeccgoto(secondEventParameters, 445) ->
 446;
yeccgoto(secondRequestedEvent, 426) ->
 428;
yeccgoto(secondRequestedEvent, 429) ->
 432;
yeccgoto(secondRequestedEventBody, 427) ->
 435;
yeccgoto(secondRequestedEvents, 428) ->
 430;
yeccgoto(secondRequestedEvents, 432) ->
 433;
yeccgoto(servChgReplyParm, 820) ->
 825;
yeccgoto(servChgReplyParm, 831) ->
 834;
yeccgoto(servChgReplyParms, 825) ->
 832;
yeccgoto(servChgReplyParms, 834) ->
 835;
yeccgoto(serviceChangeAddress, 599) ->
 612;
yeccgoto(serviceChangeAddress, 621) ->
 612;
yeccgoto(serviceChangeAddress, 820) ->
 826;
yeccgoto(serviceChangeAddress, 831) ->
 826;
yeccgoto(serviceChangeDelay, 599) ->
 613;
yeccgoto(serviceChangeDelay, 621) ->
 613;
yeccgoto(serviceChangeDescriptor, 595) ->
 597;
yeccgoto(serviceChangeMethod, 599) ->
 614;
yeccgoto(serviceChangeMethod, 621) ->
 614;
yeccgoto(serviceChangeMgcId, 599) ->
 615;
yeccgoto(serviceChangeMgcId, 621) ->
 615;
yeccgoto(serviceChangeMgcId, 820) ->
 827;
yeccgoto(serviceChangeMgcId, 831) ->
 827;
yeccgoto(serviceChangeParm, 599) ->
 616;
yeccgoto(serviceChangeParm, 621) ->
 624;
yeccgoto(serviceChangeParms, 616) ->
 622;
yeccgoto(serviceChangeParms, 624) ->
 625;
yeccgoto(serviceChangeProfile, 599) ->
 617;
yeccgoto(serviceChangeProfile, 621) ->
 617;
yeccgoto(serviceChangeProfile, 820) ->
 828;
yeccgoto(serviceChangeProfile, 831) ->
 828;
yeccgoto(serviceChangeReason, 599) ->
 618;
yeccgoto(serviceChangeReason, 621) ->
 618;
yeccgoto(serviceChangeReply, 751) ->
 768;
yeccgoto(serviceChangeReply, 769) ->
 768;
yeccgoto(serviceChangeReplyBody, 812) ->
 814;
yeccgoto(serviceChangeReplyDescriptor, 813) ->
 817;
yeccgoto(serviceChangeRequest, 127) ->
 148;
yeccgoto(serviceChangeRequest, 582) ->
 148;
yeccgoto(serviceChangeVersion, 599) ->
 619;
yeccgoto(serviceChangeVersion, 621) ->
 619;
yeccgoto(serviceChangeVersion, 820) ->
 829;
yeccgoto(serviceChangeVersion, 831) ->
 829;
yeccgoto(serviceState, 345) ->
 349;
yeccgoto(serviceStates, 333) ->
 338;
yeccgoto(serviceStates, 340) ->
 338;
yeccgoto(sigParameter, 204) ->
 213;
yeccgoto(sigParameter, 214) ->
 217;
yeccgoto(sigParameters, 213) ->
 215;
yeccgoto(sigParameters, 217) ->
 218;
yeccgoto(signalList, 192) ->
 195;
yeccgoto(signalList, 199) ->
 195;
yeccgoto(signalListId, 273) ->
 275;
yeccgoto(signalListId, 521) ->
 522;
yeccgoto(signalListParm, 276) ->
 277;
yeccgoto(signalListParm, 279) ->
 282;
yeccgoto(signalListParm, 523) ->
 524;
yeccgoto(signalListParms, 277) ->
 280;
yeccgoto(signalListParms, 282) ->
 283;
yeccgoto(signalName, 192) ->
 196;
yeccgoto(signalName, 199) ->
 196;
yeccgoto(signalName, 276) ->
 196;
yeccgoto(signalName, 279) ->
 196;
yeccgoto(signalName, 513) ->
 196;
yeccgoto(signalName, 523) ->
 196;
yeccgoto(signalParm, 192) ->
 197;
yeccgoto(signalParm, 199) ->
 202;
yeccgoto(signalParms, 197) ->
 200;
yeccgoto(signalParms, 202) ->
 203;
yeccgoto(signalRequest, 192) ->
 198;
yeccgoto(signalRequest, 199) ->
 198;
yeccgoto(signalRequest, 276) ->
 278;
yeccgoto(signalRequest, 279) ->
 278;
yeccgoto(signalRequest, 513) ->
 519;
yeccgoto(signalRequest, 523) ->
 278;
yeccgoto(signalType, 246) ->
 250;
yeccgoto(signalsDescriptor, 153) ->
 172;
yeccgoto(signalsDescriptor, 174) ->
 172;
yeccgoto(signalsDescriptor, 415) ->
 418;
yeccgoto(signalsDescriptor, 447) ->
 448;
yeccgoto(signalsDescriptor, 776) ->
 795;
yeccgoto(signalsDescriptor, 799) ->
 795;
yeccgoto(signalsDescriptor, 846) ->
 795;
yeccgoto(statisticsDescriptor, 153) ->
 173;
yeccgoto(statisticsDescriptor, 174) ->
 173;
yeccgoto(statisticsDescriptor, 316) ->
 324;
yeccgoto(statisticsDescriptor, 328) ->
 324;
yeccgoto(statisticsDescriptor, 356) ->
 324;
yeccgoto(statisticsDescriptor, 358) ->
 324;
yeccgoto(statisticsDescriptor, 776) ->
 796;
yeccgoto(statisticsDescriptor, 799) ->
 796;
yeccgoto(statisticsDescriptor, 846) ->
 796;
yeccgoto(statisticsParameter, 179) ->
 182;
yeccgoto(statisticsParameter, 183) ->
 186;
yeccgoto(statisticsParameters, 182) ->
 184;
yeccgoto(statisticsParameters, 186) ->
 187;
yeccgoto(streamDescriptor, 316) ->
 325;
yeccgoto(streamDescriptor, 328) ->
 325;
yeccgoto(streamID, 243) ->
 245;
yeccgoto(streamID, 354) ->
 355;
yeccgoto(streamID, 545) ->
 546;
yeccgoto(streamID, 574) ->
 575;
yeccgoto(streamModes, 380) ->
 386;
yeccgoto(streamParm, 316) ->
 326;
yeccgoto(streamParm, 328) ->
 326;
yeccgoto(streamParm, 356) ->
 357;
yeccgoto(streamParm, 358) ->
 361;
yeccgoto(streamParmList, 357) ->
 359;
yeccgoto(streamParmList, 361) ->
 362;
yeccgoto(subtractRequest, 127) ->
 149;
yeccgoto(subtractRequest, 582) ->
 149;
yeccgoto(terminationA, 692) ->
 693;
yeccgoto(terminationA, 696) ->
 693;
yeccgoto(terminationAudit, 776) ->
 797;
yeccgoto(terminationAudit, 846) ->
 847;
yeccgoto(terminationB, 701) ->
 702;
yeccgoto(terminationID, 150) ->
 152;
yeccgoto(terminationID, 287) ->
 289;
yeccgoto(terminationID, 290) ->
 293;
yeccgoto(terminationID, 587) ->
 588;
yeccgoto(terminationID, 593) ->
 594;
yeccgoto(terminationID, 643) ->
 644;
yeccgoto(terminationID, 692) ->
 694;
yeccgoto(terminationID, 696) ->
 694;
yeccgoto(terminationID, 701) ->
 703;
yeccgoto(terminationID, 711) ->
 712;
yeccgoto(terminationID, 714) ->
 715;
yeccgoto(terminationID, 774) ->
 775;
yeccgoto(terminationID, 811) ->
 812;
yeccgoto(terminationID, 836) ->
 837;
yeccgoto(terminationID, 842) ->
 845;
yeccgoto(terminationID, 849) ->
 289;
yeccgoto(terminationID, 862) ->
 845;
yeccgoto(terminationIDList, 285) ->
 288;
yeccgoto(terminationIDList, 843) ->
 851;
yeccgoto(terminationIDList, 863) ->
 851;
yeccgoto(terminationIDListRepeat, 289) ->
 291;
yeccgoto(terminationIDListRepeat, 293) ->
 294;
yeccgoto(terminationStateDescriptor, 316) ->
 327;
yeccgoto(terminationStateDescriptor, 328) ->
 327;
yeccgoto(terminationStateParm, 333) ->
 339;
yeccgoto(terminationStateParm, 340) ->
 343;
yeccgoto(terminationStateParms, 339) ->
 341;
yeccgoto(terminationStateParms, 343) ->
 344;
yeccgoto(timeStamp, 450) ->
 455;
yeccgoto(timeStamp, 471) ->
 455;
yeccgoto(timeStamp, 599) ->
 620;
yeccgoto(timeStamp, 621) ->
 620;
yeccgoto(timeStamp, 653) ->
 455;
yeccgoto(timeStamp, 655) ->
 455;
yeccgoto(timeStamp, 820) ->
 830;
yeccgoto(timeStamp, 831) ->
 830;
yeccgoto(topologyDescriptor, 676) ->
 686;
yeccgoto(topologyDescriptor, 687) ->
 686;
yeccgoto(topologyDirection, 704) ->
 708;
yeccgoto(topologyTriple, 692) ->
 695;
yeccgoto(topologyTriple, 696) ->
 699;
yeccgoto(topologyTripleList, 695) ->
 697;
yeccgoto(topologyTripleList, 699) ->
 700;
yeccgoto(transactionAck, 727) ->
 729;
yeccgoto(transactionAck, 730) ->
 733;
yeccgoto(transactionAckList, 729) ->
 731;
yeccgoto(transactionAckList, 733) ->
 734;
yeccgoto(transactionID, 115) ->
 719;
yeccgoto(transactionID, 735) ->
 736;
yeccgoto(transactionID, 867) ->
 868;
yeccgoto(transactionItem, 92) ->
 108;
yeccgoto(transactionItem, 108) ->
 108;
yeccgoto(transactionList, 92) ->
 109;
yeccgoto(transactionList, 108) ->
 114;
yeccgoto(transactionPending, 92) ->
 110;
yeccgoto(transactionPending, 108) ->
 110;
yeccgoto(transactionReply, 92) ->
 111;
yeccgoto(transactionReply, 108) ->
 111;
yeccgoto(transactionReplyBody, 739) ->
 743;
yeccgoto(transactionRequest, 92) ->
 112;
yeccgoto(transactionRequest, 108) ->
 112;
yeccgoto(transactionResponseAck, 92) ->
 113;
yeccgoto(transactionResponseAck, 108) ->
 113;
yeccgoto(value, 188) ->
 191;
yeccgoto(value, 219) ->
 230;
yeccgoto(value, 220) ->
 226;
yeccgoto(value, 221) ->
 225;
yeccgoto(value, 222) ->
 224;
yeccgoto(value, 227) ->
 240;
yeccgoto(value, 228) ->
 231;
yeccgoto(value, 232) ->
 238;
yeccgoto(value, 233) ->
 236;
yeccgoto(value, 633) ->
 634;
yeccgoto(valueList, 231) ->
 234;
yeccgoto(valueList, 236) ->
 237;
yeccgoto(valueList, 240) ->
 241;
yeccgoto(__Symbol, __State) ->
 exit({__Symbol, __State, missing_in_goto_table}).


